<?php
/**
 * Class for Admin Form Details
 *
 * @version 1.0
 * @package Easy Select and Share
 */

if ( ! defined( 'ABSPATH' ) ) {
	die();
}

/**
 * Easy Select and Share plugin admin side form option
 */
class ESASAdminEdit {

	/**
	 * Inital Setup
	 */
	public function __construct() {
		add_action( 'admin_init', array( $this, 'esas_register_plugin_settings' ) );
	}

	/**
	 * Register Easy Select and Share Option Settings
	 */
	public function esas_register_plugin_settings() {
		register_setting( 'esas-plugin-settings-group', 'asas_settings' );
	}

	/**
	 * Easy Select and Share plugin option setting form
	 *
	 * @return void
	 */
	public function esas_plugin_settings_page() {
		?>
		<div class="wrap form_heading">
			<?php
			// Displays success message.
			settings_errors();
			?>
			<form id="asas_admin_settings_form" method="post" action="options.php" onclick="return esas_save_order();">
				<div class="asas_top_header">
					<h3>
						<img src="<?php echo esc_url( ESAS_PLUGIN_URL . 'admin/images/logo.png' ); ?>" title="<?php esc_html_e( 'Easy Select and Share', 'easy-select-and-share' ); ?>" alt="<?php esc_html_e( 'Easy Select and Share', 'easy-select-and-share' ); ?>">
						<span class="asas_name_heading"><?php esc_html_e( 'Easy Select and Share', 'easy-select-and-share' ); ?></span>
					</h3>
					<div class="asas_button_wrap">
						<input name="submit" type="submit" class="button button-primary" id="submit" value="<?php esc_attr_e( 'Save', 'easy-select-and-share' ); ?>">
						<input name="asas_reset" type="button" class="restore-button button" value="<?php esc_attr_e( 'Restore', 'easy-select-and-share' ); ?>"/>
						<div class="loading_img_div">
							<img src="<?php echo esc_url( ESAS_PLUGIN_URL . 'admin/images/loading_image.gif' ); ?>" class="loading_img">
						</div>
					</div>
				</div>
				<?php
				settings_fields( 'esas-plugin-settings-group' );
				do_settings_sections( 'esas-plugin-settings-group' );
				$selectedobj   = new EasySelectandShare();
				$selected      = $selectedobj->esas_get_option();
				$build_options = $this->esas_social_bunch();
				?>
				<div class="asas_topdiv">
					<ul class="nav-tab-wrapper woo-nav-tab-wrapper">                        
						<li class="nav-tab asas_share_settings">
							<div class="asas_title" data-href='asas_share_settings'>
								<i class="fa fa-cogs"></i>
								<span><?php esc_html_e( 'Share Setting', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_share_items">
							<div class="asas_title" data-href='asas_share_items'>
								<i class="fa fa-share-alt-square"></i>
								<span><?php esc_html_e( 'Share with', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_widgets_preset">
							<div class="asas_title" data-href="asas_widgets_preset">
								<i class="fas fa-th-large"></i>
								<span><?php esc_html_e( 'Layout Preset', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_widgets_setting">
							<div class="asas_title" data-href="asas_widgets_setting">
								<i class="fa fa-eye"></i>
								<span><?php esc_html_e( 'Frontend Widget', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_font_setting">
							<div class="asas_title" data-href="asas_fontawesome_setting">
								<i class="fab fa-font-awesome-flag"></i>
								<span><?php esc_html_e( 'Fontawesome', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_other_setting">
							<div class="asas_title" data-href='asas_other_setting'>
								<i class="fa fa-cog"></i>
								<span><?php esc_html_e( 'Other Settings', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
						<li class="nav-tab asas_share_help">
							<div class="asas_title" data-href='asas_share_help'>
								<i class="fa fa-question"></i>
								<span><?php esc_html_e( 'Help Share-link', 'easy-select-and-share' ); ?></span>
							</div>
						</li>
					</ul>
					<div class="sas-tab-content-wrap">
						<section class="sas-content-div" id='asas_share_settings'>
							<div class="sas-col-md-7 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Supported Post Type', 'easy-select-and-share' ); ?> </div>
										<?php esc_html_e( 'Supported Post Type', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<?php
										$exlud_posttypes_arr = array( 'attachment' );
										$args                = array(
											'public' => true,
										);
										$output              = 'names'; // names or objects, note names is the default.
										$operator            = 'and';
										$post_types          = get_post_types( $args, $output, $operator );
										$supported_options   = isset( $selected['asas_supported_posttype'] ) ? $selected['asas_supported_posttype'] : array( 'post' );
										$supported_options   = is_array( $supported_options ) ? $supported_options : array( $supported_options );
										?>
										<select multiple="multiple" class="asas_supported_posttype" data-placeholder="<?php esc_html_e( 'Select Post Type', 'easy-select-and-share' ); ?>" id="asas_supported_posttype" title="<?php esc_html_e( 'Share widget will available on selected post type page', 'easy-select-and-share' ); ?>" name="asas_settings[asas_supported_posttype][]">
											<?php
											if ( is_array( $post_types ) ) {
												foreach ( $post_types as $post_type ) {
													if ( ! in_array( $post_type, $exlud_posttypes_arr, true ) ) :
														if ( ! empty( $supported_options ) ) {
															?>
															<option value="<?php echo esc_attr( $post_type ); ?>" <?php echo in_array( $post_type, $supported_options, true ) ? 'selected="selected"' : ''; ?>><?php echo esc_attr( ucfirst( $post_type ) ); ?></option>
															<?php
														} else {
															?>
															<option  value="<?php echo esc_attr( $post_type ); ?>"><?php echo esc_attr( ucfirst( $post_type ) ); ?></option>
															<?php
														}
													endif;
												}
											}
											?>
										</select>
									</div>
								</div>
								<div class="asas_row pro-feature" id="asas_supported_cat">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Supported Category', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Supported Category', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<select name="" data-placeholder="<?php esc_html_e( 'Select Categories', 'easy-select-and-share' ); ?>" multiple="multiple" class="asas_categories sas-select2-cover" id="asas_categories">
										</select>
										<p class="asas_description"><strong class="red"><?php esc_html_e( 'Note: ', 'easy-select-and-share' ); ?></strong><?php esc_html_e( 'All posts are allowed to share if no category selected', 'easy-select-and-share' ); ?></p>
									</div>
								</div>

								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select content sharing type', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Content Sharing type ', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
		<?php
		$seltext = isset( $selected['asas_share_text'] ) ? $selected['asas_share_text'] : 'sel';
		?>
										<select class="asas_text_to_share sas-select2-cover" id="asas_text_to_share" title="<?php esc_html_e( 'The text will be share as selected', 'easy-select-and-share' ); ?>" name="asas_settings[asas_share_text]">
											<option value="sel" <?php selected( $seltext, 'sel' ); ?>><?php esc_html_e( 'Page URL with selected content', 'easy-select-and-share' ); ?></option>
											<option value="con" <?php selected( $seltext, 'con' ); ?>><?php esc_html_e( 'Page URL', 'easy-select-and-share' ); ?></option>
										</select>
									</div>
								</div>                                
								<div class="asas_row conbase" style="display: none;">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Content Word Limit', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Content Word Limit', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<input type="number" min="0" max="100" step="1" name="asas_settings[asas_excerpt_limit]" value="<?php echo isset( $selected['asas_excerpt_limit'] ) ? esc_attr( $selected['asas_excerpt_limit'] ) : '60'; ?>" />
									</div>
								</div>
								<div class="asas_row pro-feature" >
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter class Which content is selectable', 'easy-select-and-share' ); ?> </div><?php esc_html_e( 'Enter class which content is selectable (using jQuery class without the dots)', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<input type="text" min="0" max="100" step="1" name="" value="" />
									</div>
								</div>
								<div class="asas_row pro-feature">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Enable shortlink url', 'easy-select-and-share' ); ?> </div><?php esc_html_e( 'Enable Shortlinks?', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<input type="checkbox" name="" value="yes" />
									</div>
								</div>
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Widget Position', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Widget Position', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
		<?php
		$asas_show_widget_position = isset( $selected['asas_show_widget_position'] ) ? $selected['asas_show_widget_position'] : 'beside_selected_text';
		?>
										<div class="asas_page_sel">
											<select id="page_sel" class="sas-select2-cover" name="asas_settings[asas_show_widget_position]">
												<option <?php selected( $asas_show_widget_position, 'beside_selected_text' ); ?> value="beside_selected_text"><?php esc_html_e( 'Beside Selected Content', 'easy-select-and-share' ); ?></option>
												<option <?php selected( $asas_show_widget_position, 'in_popup' ); ?> value="in_popup"><?php esc_html_e( 'In Popup', 'easy-select-and-share' ); ?></option>
											</select>    
										</div>
										<div class="asas_page_con">
											<select id="page_con" class="sas-select2-cover" name="asas_settings[asas_show_widget_position]">
												<option <?php selected( $asas_show_widget_position, 'after_content' ); ?> value="after_content"><?php esc_html_e( 'After Content', 'easy-select-and-share' ); ?></option>
												<option <?php selected( $asas_show_widget_position, 'before_content' ); ?> value="before_content"><?php esc_html_e( 'Before Content', 'easy-select-and-share' ); ?></option>
											</select>
										</div>
									</div>
								</div>
							</div>
						</section>
						<section class="sas-content-div" id='asas_share_items'>
							<div class="sas-col-md-7 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Share With', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Select Share With', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12 sas-social-share-with-wrap">
		<?php
		$asas_social_order = get_option( 'asas_social_order' );
		if ( isset( $selected['share_select'] ) && ! empty( $selected['share_select'] ) ) {
			$share_select = $selected['share_select'];
		} else {
			$share_select = array( 'twitter', 'linkedin' );
		}
		?>
										<select data-order='<?php echo esc_attr( $asas_social_order ); ?>' multiple="multiple" class="chosen-select" data-placeholder="<?php esc_html_e( 'Select Social Share options', 'easy-select-and-share' ); ?>"  name="asas_settings[share_select][]" id="share_select">
										<?php
										foreach ( $build_options as $key => $val ) {
											$class = '';
											if ( 'facebook' === $key ) {
												$class = 'facebook_se';
											}
											if ( ! empty( $share_select ) ) {
												?>
													<option class="<?php echo esc_attr( $class ); ?>" value="<?php echo esc_attr( $key ); ?>" <?php echo in_array( $key, $share_select, true ) ? 'selected="selected"' : ''; ?>><?php echo esc_attr( $val['name'] ); ?></option>
													<?php
											} else {
												?>
													<option class="<?php echo esc_attr( $class ); ?>" value="<?php echo esc_attr( $key ); ?>"><?php echo esc_attr( $val['name'] ); ?></option>
													<?php
											}
										}
										?>
										</select>
										<note><b>Note:</b> To display Facebook icon, user need to add APP ID in Other Settings.</note>
									</div>
								</div>
							</div>
							<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 pro-feature">
								<div class="table-responsive">
									<table class="sas-custom-links-tbl asas_custom_share_link_tbl ">
										<thead>
											<tr>
												<th>
												<?php
												esc_html_e( 'Share Button Text', 'easy-select-and-share' );
												?>
												</th>
												<th><?php esc_html_e( 'Share URL', 'easy-select-and-share' ); ?></th>
												<th class="sas-social-share-image"> <?php esc_html_e( 'Share Image', 'easy-select-and-share' ); ?><br><small><span class="red"><?php esc_html_e( 'Note', 'easy-select-and-share' ); ?>: &nbsp;</span><?php esc_html_e( 'Image size should be', 'easy-select-and-share' ); ?>&nbsp;40px * 40px</small></th>
												<th class="sas-social-share-icon"> <?php esc_html_e( 'Share Icon', 'easy-select-and-share' ); ?></th>
												<th></th>
											</tr>
										</thead>
										<tbody>
											<tr>
												<td class="sas-table-footer" colspan="1">
													<a href="javascript:void(0);" data-id="asas_custom_share_link_tbl" class="asas_add_custom_share_link button-secondary" disabled="disabled">
														<b>
															<i class="fa fa-plus-circle"></i>&nbsp;
		<?php esc_html_e( 'Add Custom Share Link', 'easy-select-and-share' ); ?>
														</b>
													</a>
												</td>
												<td class="sas-table-footer" colspan="3">
													<strong><?php esc_html_e( 'Help', 'easy-select-and-share' ); ?>:</strong>
													<abbr class="asas_tags" title="<?php esc_html_e( 'Use this tag in your custom share url to share post url', 'easy-select-and-share' ); ?>.">{url}</abbr>
													<abbr class="asas_tags" title="<?php esc_html_e( 'Use this tag in your custom share url to share post title', 'easy-select-and-share' ); ?>.">{title}</abbr>
													<abbr class="asas_tags" title="<?php esc_html_e( 'Use this tag in your custom share url to share post excerpt', 'easy-select-and-share' ); ?>.">{excerpt}</abbr>
													<div>
														<strong><?php esc_html_e( 'Example', 'easy-select-and-share' ); ?>:</strong>
														http://www.example.com/share.php?variable1={url}&variable2={title}...
													</div>
												</td>
											</tr>
										</tbody>
									</table>
									<div class="saspro-dialogbox" title="<?php esc_html_e( 'Select Icon', 'easy-select-and-share' ); ?>" style="display:none">
										<input type="hidden" value="" class="hidden_input_val"/>
										<input type="text" id="icon_search" placeholder="<?php esc_attr_e( 'Search icon', 'easy-select-and-share' ); ?>">
										<div class="icon_div"></div>
									</div>
								</div>
							</div>
						</section>
						<section class="sas-content-div" id='asas_widgets_preset'>
							<div class="sas-col-xs-12">
								<div class="asas_row sas-col-xs-12 padding-right-0 padding-left-0">
									<div class="sas-col-sm-12 sas-col-xs-12 sas-title">
										<h3><?php esc_html_e( 'Select Layout', 'easy-select-and-share' ); ?></h3>
										<p><?php esc_html_e( 'Select your favorite layout from 10+ powerful layouts', 'easy-select-and-share' ); ?></p>
		<?php $preset = ( isset( $selected['esc_layout_preset'] ) && '' !== $selected['esc_layout_preset'] ) ? $selected['esc_layout_preset'] : 'esc_layout_preset_5'; ?>
										<input class="asas_select_template button" type="button" value="<?php esc_html_e( 'Select Other Layout', 'easy-select-and-share' ); ?>">
										<input name="asas_settings[esc_layout_preset]" id="template_name" value="<?php echo esc_attr( $preset ); ?>" type="hidden">
										<br/><br/><br/><br/><br/><br/><br/>
									</div>
									<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
		<?php esc_html_e( 'Current Preset', 'easy-select-and-share' ); ?> : 
									</label>
									<div class="sas-col-sm-10 sas-col-xs-12">
										<div class="esc_current_preset">
											<div class="esc_layout_preset_theme <?php echo esc_attr( $preset ); ?>">
												<label>
													<span></span>
												</label>
											</div>
										</div>
										<div class="esc_layout_preset" style="display:none">
		<?php
		$icon_text_array = array( '0', '1', '2', '3', '4', '9', '10', '16' );
		for ( $i = 0; $i <= 22; $i++ ) {
			$icon_class_pro = '';
			if ( in_array( $i, $icon_text_array ) ) {
				$icon_class_pro = 'pro-feature';
			}
			?>
												<div class="esc_layout_preset_theme esc_layout_preset_<?php echo esc_attr( $i ); ?> <?php echo esc_attr( $icon_class_pro ); ?>">
													<label>
														<?php if ( ! in_array( $i, $icon_text_array ) ) { ?>
														<input type="radio" name="asas_settings[esc_layout_preset1]" id="esc_layout_preset_<?php echo esc_attr( $i ); ?>" value="esc_layout_preset_<?php echo esc_attr( $i ); ?>" <?php checked( 'esc_layout_preset_' . $i, $preset ); ?>>
														<?php } ?> 
														<span></span>
													</label>
												</div>
				<?php
		}
		?>
										</div>
									</div>
								</div>
							</div>
						</section>
						<section class="sas-content-div" id='asas_widgets_setting'>
							<div class="sas-col-xs-12">
								<div class="asas_row sas-col-xs-12 padding-right-0 padding-left-0">
									<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Share Button Type', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Share Button Type', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-7 sas-col-xs-12">
										<?php
										$btntype = ( isset( $selected['asas_share_button_type'] ) && '' !== $selected['asas_share_button_type'] ) ? $selected['asas_share_button_type'] : 'icon';
										?>
										<select class="asas_share_button_type sas-select2-cover" id="asas_share_button_type"  name="asas_settings[asas_share_button_type]">
											<option value="icon" <?php selected( $btntype, 'icon' ); ?> ><?php esc_html_e( 'Icon', 'easy-select-and-share' ); ?></option>
											<option value="img" <?php selected( $btntype, 'img' ); ?>><?php esc_html_e( 'Image', 'easy-select-and-share' ); ?></option>
										</select>
									</div>
								</div>
								<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 button_type_icon border-separater padding-right-0 padding-left-0">
									<div class="asas_row">
										<h4 class="sas-col-xs-12"><?php esc_html_e( 'Icon Setting', 'easy-select-and-share' ); ?></h4>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Icon Color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_text_color]" value="<?php echo isset( $selected['asas_icon_text_color'] ) ? esc_attr( $selected['asas_icon_text_color'] ) : '#fff'; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Icon Background color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Background color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_bgcolor]" value="<?php echo isset( $selected['asas_icon_bgcolor'] ) ? esc_attr( $selected['asas_icon_bgcolor'] ) : ''; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Icon Font Size', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Font Size', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Font Size', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_font_size]" value="<?php echo isset( $selected['asas_icon_font_size'] ) ? esc_attr( $selected['asas_icon_font_size'] ) : '16'; ?>" />px
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Icon Line height', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Line height', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Line height', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_line_height]" value="<?php echo isset( $selected['asas_icon_line_height'] ) ? esc_attr( $selected['asas_icon_line_height'] ) : '16'; ?>" />px
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title sas-padding-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Icon Padding', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Padding', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Top', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Top Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_padding_top]" value="<?php echo isset( $selected['asas_icon_padding_top'] ) ? esc_attr( $selected['asas_icon_padding_top'] ) : '10'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Bottom', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Bottom Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_padding_bottom]" value="<?php echo isset( $selected['asas_icon_padding_bottom'] ) ? esc_attr( $selected['asas_icon_padding_bottom'] ) : '10'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Left', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Left Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_padding_left]" value="<?php echo isset( $selected['asas_icon_padding_left'] ) ? esc_attr( $selected['asas_icon_padding_left'] ) : '10'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Right', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Right Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_padding_right]" value="<?php echo isset( $selected['asas_icon_padding_right'] ) ? esc_attr( $selected['asas_icon_padding_right'] ) : '10'; ?>" />px
											</div>
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Border for Icon', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<?php
											$border_top_type    = ( isset( $selected['asas_icon_border_type'] ) && '' !== $selected['asas_icon_border_type'] ) ? $selected['asas_icon_border_type'] : 'solid';
											$border_bottom_type = ( isset( $selected['asas_icon_border_bottom_type'] ) && '' !== $selected['asas_icon_border_bottom_type'] ) ? $selected['asas_icon_border_bottom_type'] : 'solid';
											$border_left_type   = ( isset( $selected['asas_icon_border_left_type'] ) && '' !== $selected['asas_icon_border_left_type'] ) ? $selected['asas_icon_border_left_type'] : 'solid';
											$border_right_type  = ( isset( $selected['asas_icon_border_right_type'] ) && '' !== $selected['asas_icon_border_right_type'] ) ? $selected['asas_icon_border_right_type'] : 'solid';
											?>
											<div class="">
											<?php esc_html_e( 'Top', 'easy-select-and-share' ); ?>
												<div class="sas-border-wrap">
													<div class="sas-col-xs-4 padding-left-0">
														<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_border_width]" value="<?php echo isset( $selected['asas_icon_border_width'] ) ? esc_attr( $selected['asas_icon_border_width'] ) : '0'; ?>" />px
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<select class="asas_icon_border_type sas-select2-cover" id="asas_icon_border_type"  name="asas_settings[asas_icon_border_type]">
															<option value="solid" <?php selected( $border_top_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
															<option value="dotted" <?php selected( $border_top_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
															<option value="dashed" <?php selected( $border_top_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
															<option value="double" <?php selected( $border_top_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
														</select>
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_border_color]" value="<?php echo isset( $selected['asas_icon_border_color'] ) ? esc_attr( $selected['asas_icon_border_color'] ) : ''; ?>" />
													</div>
												</div>
											</div>
											<div class="">
		<?php esc_html_e( 'Bottom', 'easy-select-and-share' ); ?>
												<div class="sas-border-wrap">
													<div class="sas-col-xs-4 padding-left-0">
														<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_border_bottom_width]" value="<?php echo isset( $selected['asas_icon_border_bottom_width'] ) ? esc_attr( $selected['asas_icon_border_bottom_width'] ) : '0'; ?>" />px
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<select class="asas_icon_border_bottom_type sas-select2-cover" id="asas_icon_border_bottom_type"  name="asas_settings[asas_icon_border_bottom_type]">
															<option value="solid" <?php selected( $border_bottom_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
															<option value="dotted" <?php selected( $border_bottom_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
															<option value="dashed" <?php selected( $border_bottom_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
															<option value="double" <?php selected( $border_bottom_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
														</select>
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_border_bottom_color]" value="<?php echo isset( $selected['asas_icon_border_bottom_color'] ) ? esc_attr( $selected['asas_icon_border_bottom_color'] ) : ''; ?>" />
													</div>
												</div>
											</div>
											<div class="">
		<?php esc_html_e( 'Left', 'easy-select-and-share' ); ?>
												<div class="sas-border-wrap">
													<div class="sas-col-xs-4 padding-left-0">
														<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_border_left_width]" value="<?php echo isset( $selected['asas_icon_border_left_width'] ) ? esc_attr( $selected['asas_icon_border_left_width'] ) : '0'; ?>" />px
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<select class="asas_icon_border_left_type sas-select2-cover" id="asas_icon_border_left_type"  name="asas_settings[asas_icon_border_left_type]">
															<option value="solid" <?php selected( $border_left_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
															<option value="dotted" <?php selected( $border_left_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
															<option value="dashed" <?php selected( $border_left_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
															<option value="double" <?php selected( $border_left_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
														</select>
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_border_left_color]" value="<?php echo isset( $selected['asas_icon_border_left_color'] ) ? esc_attr( $selected['asas_icon_border_left_color'] ) : ''; ?>" />
													</div>
												</div>
											</div>
											<div class="">
		<?php esc_html_e( 'Right', 'easy-select-and-share' ); ?>
												<div class="sas-border-wrap">
													<div class="sas-col-xs-4 padding-left-0">
														<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_border_right_width]" value="<?php echo isset( $selected['asas_icon_border_right_width'] ) ? esc_attr( $selected['asas_icon_border_right_width'] ) : '0'; ?>" />px
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<select class="asas_icon_border_right_type sas-select2-cover" id="asas_icon_border_right_type"  name="asas_settings[asas_icon_border_right_type]">
															<option value="solid" <?php selected( $border_right_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
															<option value="dotted" <?php selected( $border_right_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
															<option value="dashed" <?php selected( $border_right_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
															<option value="double" <?php selected( $border_right_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
														</select>
													</div>
													<div class="sas-col-xs-4 padding-left-0">
														<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_icon_border_right_color]" value="<?php echo isset( $selected['asas_icon_border_right_color'] ) ? esc_attr( $selected['asas_icon_border_right_color'] ) : ''; ?>" />
													</div>
												</div>
											</div>
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Icon Border Radius', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border Radius', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Icon Border Radius', 'easy-select-and-share' ); ?>" name="asas_settings[asas_icon_border_radius]" value="<?php echo isset( $selected['asas_icon_border_radius'] ) ? esc_attr( $selected['asas_icon_border_radius'] ) : '15'; ?>" />
											</div>
											<div class="sas-col-xs-4 padding-left-0">
												<?php $border_rad_type = ( isset( $selected['asas_icon_border_rad_type'] ) && '' !== $selected['asas_icon_border_rad_type'] ) ? esc_html( $selected['asas_icon_border_rad_type'] ) : '%'; ?>
												<select class="asas_icon_border_rad_type sas-select2-cover" id="asas_icon_border_rad_type"  name="asas_settings[asas_icon_border_rad_type]">
													<option value="px" <?php selected( $border_rad_type, 'px' ); ?>>px</option>
													<option value="%" <?php selected( $border_rad_type, '%' ); ?>>%</option>
												</select>
											</div>
										</div>
									</div>
									<div class="asas_row asas_icon_text_type">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Icon Position', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Icon Position', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<?php
											$icon_position = ( isset( $selected['asas_share_icon_position'] ) && '' !== $selected['asas_share_icon_position'] ) ? esc_attr( $selected['asas_share_icon_position'] ) : 'left';
											?>
											<div class="sas-col-xs-4 padding-left-0">
												<select class="asas_share_icon_position sas-select2-cover" id="asas_share_icon_position"  name="asas_settings[asas_share_icon_position]">
													<option value="top" <?php selected( $icon_position, 'top' ); ?>><?php esc_html_e( 'Top', 'easy-select-and-share' ); ?></option>
													<option value="bottom" <?php selected( $icon_position, 'bottom' ); ?>><?php esc_html_e( 'Bottom', 'easy-select-and-share' ); ?></option>
													<option value="left" <?php selected( $icon_position, 'left' ); ?>><?php esc_html_e( 'Left', 'easy-select-and-share' ); ?></option>
													<option value="right" <?php selected( $icon_position, 'right' ); ?>><?php esc_html_e( 'Right', 'easy-select-and-share' ); ?></option>
												</select>
											</div>
										</div>
									</div>
								</div>

								<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 button_type_text border-separater padding-right-0 padding-left-0">
									<div class="asas_row">
										<h4 class="sas-col-xs-12"><?php esc_html_e( 'Text Setting', 'easy-select-and-share' ); ?></h4>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Text Font Size', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Text Font Size', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Text Font Size', 'easy-select-and-share' ); ?>" name="asas_settings[asas_text_font_size]" value="<?php echo isset( $selected['asas_text_font_size'] ) ? esc_attr( $selected['asas_text_font_size'] ) : '14'; ?>" />px
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Text Color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Text Color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_text_color]" value="<?php echo isset( $selected['asas_text_color'] ) ? esc_attr( $selected['asas_text_color'] ) : '#ffffff'; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title sas-padding-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Text Padding', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Padding', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Top', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Text Top Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_text_padding_top]" value="<?php echo isset( $selected['asas_text_padding_top'] ) ? esc_attr( $selected['asas_text_padding_top'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Right', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Text Right Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_text_padding_right]" value="<?php echo isset( $selected['asas_text_padding_right'] ) ? esc_attr( $selected['asas_text_padding_right'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Bottom', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Text Bottom Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_text_padding_bottom]" value="<?php echo isset( $selected['asas_text_padding_bottom'] ) ? esc_attr( $selected['asas_text_padding_bottom'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Left', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Text Left Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_text_padding_left]" value="<?php echo isset( $selected['asas_text_padding_left'] ) ? esc_attr( $selected['asas_text_padding_left'] ) : '0'; ?>" />px
											</div>
										</div>
									</div>
								</div>

								<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 button_type_image border-separater padding-right-0 padding-left-0">
									<div class="asas_row">
										<h4 class="sas-col-xs-12"><?php esc_html_e( 'Image Settings', 'easy-select-and-share' ); ?></h4>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Image Layout', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Image Layouts', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-10 sas-col-xs-12">
											<?php
											$image_layout = ( isset( $selected['asas_image_layout'] ) && '' !== $selected['asas_image_layout'] ) ? esc_attr( $selected['asas_image_layout'] ) : 'asas_image_layout_1';
											for ( $layout = 1; $layout <= 5; $layout++ ) {
												?>
												<div class="esc_image_layout_preset esc_image_layout_<?php echo esc_attr( $layout ); ?>">
													<label>
														<input type="radio" name="asas_settings[asas_image_layout]" <?php checked( 'asas_image_layout_' . $layout, $image_layout ); ?> class="esc_image_layout_<?php echo esc_attr( $layout ); ?>" value="asas_image_layout_<?php echo esc_attr( $layout ); ?>"/>
														<span></span>
													</label>
												</div>
												<?php
											}
											?>
										</div>
									</div>
								</div>

								<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 asas_box_setting border-separater padding-right-0 padding-left-0">
									<div class="asas_row">
										<h4 class="sas-col-xs-12"><?php esc_html_e( 'Box Setting', 'easy-select-and-share' ); ?></h4>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enable Box Shadow', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Enable Box Shadow', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12 enable_box_shadow">
											<?php
											$show_box_shadow = ( isset( $selected['asas_show_box_shadow'] ) && '' !== $selected['asas_show_box_shadow'] ) ? esc_attr( $selected['asas_show_box_shadow'] ) : 0;
											?>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_show_box_shadow]" value="1" <?php checked( '1', $show_box_shadow ); ?> />
		<?php esc_html_e( 'Yes', 'easy-select-and-share' ); ?>
												</label>
											</div>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_show_box_shadow]" value="0" <?php checked( '0', $show_box_shadow ); ?> />
		<?php esc_html_e( 'No', 'easy-select-and-share' ); ?>
												</label>
											</div>
										</div>
									</div>
									<div class="asas_row asas_box_shadow_color_wrapper">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Box Shadow Color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Box Shadow color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_box_shadow_color]" value="<?php echo isset( $selected['asas_box_shadow_color'] ) ? esc_attr( $selected['asas_box_shadow_color'] ) : ''; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title sas-padding-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Box Padding', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Padding', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Top', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Box Top Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_padding_top]" value="<?php echo isset( $selected['asas_box_padding_top'] ) ? esc_attr( $selected['asas_box_padding_top'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Right', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Box Right Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_padding_right]" value="<?php echo isset( $selected['asas_box_padding_right'] ) ? esc_attr( $selected['asas_box_padding_right'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Bottom', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Box Bottom Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_padding_bottom]" value="<?php echo isset( $selected['asas_box_padding_bottom'] ) ? esc_attr( $selected['asas_box_padding_bottom'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-3 padding-left-0">
		<?php esc_html_e( 'Left', 'easy-select-and-share' ); ?><br/>
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Box Left Padding', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_padding_left]" value="<?php echo isset( $selected['asas_box_padding_left'] ) ? esc_attr( $selected['asas_box_padding_left'] ) : '0'; ?>" />px
											</div>
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Box Background color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Background color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_box_bgcolor]" value="<?php echo isset( $selected['asas_box_bgcolor'] ) ? esc_attr( $selected['asas_box_bgcolor'] ) : ''; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Border for Box', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border', 'easy-select-and-share' ); ?>
										</label>
											<?php
											$box_border_type = ( isset( $selected['asas_share_box_border_type'] ) && '' !== $selected['asas_share_box_border_type'] ) ? esc_attr( $selected['asas_share_box_border_type'] ) : 'solid';
											?>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" min="0" step="1" placeholder=" <?php esc_html_e( 'Enter Box Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_border_width]" value="<?php echo isset( $selected['asas_box_border_width'] ) ? esc_attr( $selected['asas_box_border_width'] ) : '0'; ?>" />px
											</div>
											<div class="sas-col-xs-4 padding-left-0">
												<select class="asas_share_box_border_type sas-select2-cover" id="asas_share_box_border_type"  name="asas_settings[asas_share_box_border_type]">
													<option value="solid" <?php selected( $box_border_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
													<option value="dotted" <?php selected( $box_border_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
													<option value="dashed" <?php selected( $box_border_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
													<option value="double" <?php selected( $box_border_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
												</select>
											</div>
											<div class="sas-col-xs-4 padding-left-0">
												<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_box_border_color]" value="<?php echo isset( $selected['asas_box_border_color'] ) ? esc_attr( $selected['asas_box_border_color'] ) : ''; ?>" />
											</div>
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Box Border Radius', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border Radius', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Box Border Radius', 'easy-select-and-share' ); ?>" name="asas_settings[asas_box_border_radius]" value="<?php echo isset( $selected['asas_box_border_radius'] ) ? esc_attr( $selected['asas_box_border_radius'] ) : '5'; ?>" />
											</div>
											<div class="sas-col-xs-4 padding-left-0">
		<?php $border_rad_type = ( isset( $selected['asas_box_border_rad_type'] ) && '' !== $selected['asas_box_border_rad_type'] ) ? esc_html( $selected['asas_box_border_rad_type'] ) : '%'; ?>
												<select class="asas_box_border_rad_type sas-select2-cover" id="asas_box_border_rad_type"  name="asas_settings[asas_box_border_rad_type]">
													<option value="px" <?php selected( $border_rad_type, 'px' ); ?>>px</option>
													<option value="%" <?php selected( $border_rad_type, '%' ); ?>>%</option>
												</select>
											</div>
										</div>
									</div>
								</div>
								<div class="sas-col-md-12 sas-col-sm-12 sas-col-xs-12 padding-right-0 padding-left-0">
									<div class="asas_row">
										<h4 class="sas-col-xs-12"><?php esc_html_e( 'Widget Setting', 'easy-select-and-share' ); ?></h4>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Widget Title here', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Widget Title', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-5 sas-col-xs-12">
											<input type="text" placeholder="<?php esc_html_e( 'Enter Share widget title or leave it blank to disable title', 'easy-select-and-share' ); ?>" name="asas_settings[asas_widget_title]" value="<?php echo isset( $selected['asas_widget_title'] ) ? esc_attr( $selected['asas_widget_title'] ) : ''; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Title color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Title color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_title_color]" value="<?php echo isset( $selected['asas_title_color'] ) ? esc_attr( $selected['asas_title_color'] ) : '#000'; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Title Background color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Title Background color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_title_background]" value="<?php echo isset( $selected['asas_title_background'] ) ? esc_attr( $selected['asas_title_background'] ) : '#ffffff'; ?>" />
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Widget Background color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Widget Background color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_widget_background]" value="<?php echo ( isset( $selected['asas_widget_background'] ) && ! empty( $selected['asas_widget_background'] ) ) ? esc_attr( $selected['asas_widget_background'] ) : '#ffffff'; ?>" />
										</div>
									</div>
									<div class="asas_row asas_show_in_popup_only">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Border for Widget', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<?php
											$widget_border_type = ( isset( $selected['asas_share_widget_border_type'] ) && '' !== $selected['asas_share_widget_border_type'] ) ? esc_attr( $selected['asas_share_widget_border_type'] ) : 'solid';
											?>
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Widget Border Width', 'easy-select-and-share' ); ?>" name="asas_settings[asas_share_widget_border_width]" value="<?php echo isset( $selected['asas_share_widget_border_width'] ) ? esc_attr( $selected['asas_share_widget_border_width'] ) : '1'; ?>">px
											</div>
											<div class="sas-col-xs-4 padding-left-0">
												<select class="asas_share_box_border_type sas-select2-cover" id="asas_share_widget_border_type" name="asas_settings[asas_share_widget_border_type]">
													<option value="solid" <?php selected( $widget_border_type, 'solid' ); ?>><?php esc_html_e( 'Solid', 'easy-select-and-share' ); ?></option>
													<option value="dotted" <?php selected( $widget_border_type, 'dotted' ); ?>><?php esc_html_e( 'Dotted', 'easy-select-and-share' ); ?></option>
													<option value="dashed" <?php selected( $widget_border_type, 'dashed' ); ?>><?php esc_html_e( 'Dash', 'easy-select-and-share' ); ?></option>
													<option value="double" <?php selected( $widget_border_type, 'double' ); ?>><?php esc_html_e( 'Double', 'easy-select-and-share' ); ?></option>
												</select>
											</div>
											<div class="sas-col-xs-4 padding-left-0 asas_show_in_popup_only">
												<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_widget_border_color]" value="<?php echo isset( $selected['asas_widget_border_color'] ) ? esc_attr( $selected['asas_widget_border_color'] ) : '#e2e2e2'; ?>" />
											</div>
										</div>
									</div>
									<div class="asas_row asas_show_in_popup_only">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Widget Border Radius', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Border Radius', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" max="100" min="0" step="1" placeholder="<?php esc_html_e( 'Enter Widget Border Radius', 'easy-select-and-share' ); ?>" name="asas_settings[asas_widget_border_radius]" value="<?php echo isset( $selected['asas_widget_border_radius'] ) ? esc_attr( $selected['asas_widget_border_radius'] ) : '0'; ?>" />
											</div>
											<div class="sas-col-xs-4 padding-left-0">
		<?php $border_rad_type = ( isset( $selected['asas_widget_border_rad_type'] ) && '' !== $selected['asas_widget_border_rad_type'] ) ? esc_html( $selected['asas_widget_border_rad_type'] ) : '%'; ?>
												<select class="asas_widget_border_rad_type sas-select2-cover" id="asas_widget_border_rad_type"  name="asas_settings[asas_widget_border_rad_type]">
													<option value="px" <?php selected( $border_rad_type, 'px' ); ?>>px</option>
													<option value="%" <?php selected( $border_rad_type, '%' ); ?>>%</option>
												</select>
											</div>
										</div>
									</div>
									<div class="asas_row asas_show_in_popup_only">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enable Box Shadow', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Enable Box Shadow', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12 enable_box_shadow">
											<?php
											$show_widget_box_shadow = ( isset( $selected['asas_show_widget_box_shadow'] ) && '' !== $selected['asas_show_widget_box_shadow'] ) ? esc_attr( $selected['asas_show_widget_box_shadow'] ) : 0;
											?>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_show_widget_box_shadow]" value="1" <?php checked( '1', $show_widget_box_shadow ); ?> />
		<?php esc_html_e( 'Yes', 'easy-select-and-share' ); ?>
												</label>
											</div>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_show_widget_box_shadow]" value="0" <?php checked( '0', $show_widget_box_shadow ); ?> />
		<?php esc_html_e( 'No', 'easy-select-and-share' ); ?>
												</label>
											</div>
										</div>
									</div>
									<div class="asas_row asas_widget_box_shadow_color asas_show_in_popup_only">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Select Box Shadow color', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Box Shadow color', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<input class="asas_color_picker" data-alpha="true" type="text" name="asas_settings[asas_widget_box_shadow_color]" value="<?php echo isset( $selected['asas_widget_box_shadow_color'] ) ? esc_attr( $selected['asas_widget_box_shadow_color'] ) : ''; ?>" />                                            
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter width of widget', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Widget width', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12">
											<div class="sas-col-xs-4 padding-left-0">
												<input type="number" min="0" step="1" placeholder="<?php esc_html_e( 'Enter width of Widget', 'easy-select-and-share' ); ?>" name="asas_settings[asas_widget_width]" value="<?php echo isset( $selected['asas_widget_width'] ) ? esc_attr( $selected['asas_widget_width'] ) : ''; ?>" />
											</div>
											<div class="sas-col-xs-4 padding-left-0">
		<?php $asas_widget_width_type = ( isset( $selected['asas_widget_width_type'] ) && '' !== $selected['asas_widget_width_type'] ) ? esc_html( $selected['asas_widget_width_type'] ) : '%'; ?>
												<select class="asas_widget_width_type sas-select2-cover" id="asas_widget_width_type"  name="asas_settings[asas_widget_width_type]">
													<option value="px" <?php selected( $asas_widget_width_type, 'px' ); ?>>px</option>
													<option value="%" <?php selected( $asas_widget_width_type, '%' ); ?>>%</option>
												</select>
											</div>
										</div>
									</div>
									<div class="asas_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter extra class for widget', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Widget extra class', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-5 sas-col-xs-12">
											<input type="text" placeholder="<?php esc_html_e( 'Enter class name for share widget', 'easy-select-and-share' ); ?>" name="asas_settings[asas_widget_extra_class]" value="<?php echo isset( $selected['asas_widget_extra_class'] ) ? esc_attr( $selected['asas_widget_extra_class'] ) : ''; ?>" />
										</div>
									</div>
									<div class="asas_row close_button_row">
										<label class="sas-col-sm-2 sas-col-xs-12 sas-title">
											<div class="sas-title-tooltip"> <?php esc_html_e( 'Display Close Button', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Display Close Button', 'easy-select-and-share' ); ?>
										</label>
										<div class="sas-col-sm-7 sas-col-xs-12 enable_close_button">
											<?php
											$asas_display_close_button = ( isset( $selected['asas_display_close_button'] ) && '' !== $selected['asas_display_close_button'] ) ? esc_attr( $selected['asas_display_close_button'] ) : 1;
											?>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_display_close_button]" value="1" <?php checked( '1', $asas_display_close_button ); ?> />
		<?php esc_html_e( 'Yes', 'easy-select-and-share' ); ?>
												</label>
											</div>
											<div>
												<label>
													<input type="radio" name="asas_settings[asas_display_close_button]" value="0" <?php checked( '0', $asas_display_close_button ); ?> />
		<?php esc_html_e( 'No', 'easy-select-and-share' ); ?>
												</label>
											</div>
										</div>
									</div>
								</div>
							</div>
						</section>
						<section class="sas-content-div" id='asas_fontawesome_setting'>
							<div class="sas-col-md-7 sas-col-xs-12 pro-feature">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Check this box to disable font awesome at front end', 'easy-select-and-share' ); ?> </div><?php esc_html_e( 'Disable font awesome?', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12 ">
										<input type="checkbox" name="" <?php echo isset( $selected['disable_fontawesome'] ) ? checked( $selected['disable_fontawesome'], 'yes' ) : ''; ?> value="yes" />
									</div>
								</div>
							</div>
							<?php
							$build_options = $this->esas_social_bunch();
							if ( isset( $build_options ) ) {
								foreach ( $build_options as $key => $val_ary ) {
									$icon_txt  = isset( $val_ary['name'] ) ? $val_ary['name'] : '';
									$icon      = isset( $val_ary['icon'] ) ? $val_ary['icon'] : '';
									$icon_name = $key . '_icon';
									?>
									<div class="sas-col-md-7 sas-col-xs-12">
										<div class="asas_row pro-feature">
											<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
												<div class="sas-title-tooltip"> 
												<?php
												echo esc_html( $icon_txt ) . ' ';
												esc_html_e( 'Icon', 'easy-select-and-share' );
												?>
												</div>
												<?php
												echo esc_html( $icon_txt ) . ' ';
												esc_html_e( 'Icon', 'easy-select-and-share' );
												?>
											</label>
											<div class="sas-col-sm-8 sas-col-xs-12">
												<input type="text" name="asas_settings[<?php echo esc_attr( $icon_name ); ?>]" value="<?php echo isset( $selected[ $icon_name ] ) ? esc_attr( $selected[ $icon_name ] ) : esc_attr( $icon ); ?>" />
											</div>
										</div>
									</div>
									<?php
								}
							}
							?>

						</section>
						<section class="sas-content-div" id='asas_other_setting'>
							<div class="sas-col-md-7 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Twitter User name', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Twitter User Name', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<input type="text" placeholder="<?php esc_html_e( 'Enter Twitter User name', 'easy-select-and-share' ); ?>" name="asas_settings[twitter_username]" value="<?php echo isset( $selected['twitter_username'] ) ? esc_attr( $selected['twitter_username'] ) : ''; ?>" />
									</div>
								</div>
							</div>
							<div class="sas-col-md-7 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Facebook App ID', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Facebook App ID', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<input type="text" placeholder="<?php esc_html_e( 'Enter Facebook App ID', 'easy-select-and-share' ); ?>" name="asas_settings[facebook_appid]" value="<?php echo isset( $selected['facebook_appid'] ) ? esc_attr( $selected['facebook_appid'] ) : ''; ?>" />
										<note><a href="https://developers.facebook.com/apps"><?php esc_html_e( 'Requires a Facebook developer application.', 'easy-select-and-share' ); ?></a> This field is compulsory to share content on facebook</note>
									</div>
								</div>
							</div>
							<div class="sas-col-md-7 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-4 sas-col-xs-12 sas-title">
										<div class="sas-title-tooltip"> <?php esc_html_e( 'Enter Custom CSS', 'easy-select-and-share' ); ?> </div>
		<?php esc_html_e( 'Custom CSS', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-8 sas-col-xs-12">
										<textarea placeholder="<?php esc_html_e( 'Enter Custom CSS', 'easy-select-and-share' ); ?>" name="asas_settings[asas_custom_css]"><?php echo isset( $selected['asas_custom_css'] ) ? esc_html( $selected['asas_custom_css'] ) : ''; ?></textarea>
									</div>
								</div>
							</div>
						</section>
						<section class="sas-content-div" id='asas_share_help'>
							<div class="sas-col-md-10 sas-col-sm-12 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-3 sas-col-xs-12 sas-title">
		<?php esc_html_e( 'Twitter Share URL', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-9 sas-col-xs-12">
										<p><?php echo 'https://twitter.com/intent/tweet?url={url}&text={excerpt}'; ?></p>
									</div>
								</div>
							</div>
							<div class="sas-col-md-10 sas-col-sm-12 sas-col-xs-12">
								<div class="asas_row">
									<label class="sas-col-sm-3 sas-col-xs-12 sas-title">
		<?php esc_html_e( 'Linkedin Share URL', 'easy-select-and-share' ); ?>
									</label>
									<div class="sas-col-sm-9 sas-col-xs-12">
										<p><?php echo 'https://www.linkedin.com/shareArticle?mini=true&url={url}&title={title}&summary={excerpt}&source={url}&text={text}'; ?></P>
									</div>
								</div>
							</div>
						</section>
					</div>
				</div>
			</form>
			<div id="sas-advertisement-popup">
				<div class="sas-advertisement-cover">
					<a class="sas-advertisement-link" target="_blank" href="https://codecanyon.net/item/easy-select-and-share-pro/32023012">
						<img src="<?php echo esc_url( ESAS_PLUGIN_URL . 'admin/images/banner_image_main.png' ); ?>" />
					</a>
				</div>
			</div>
		</div>
		<?php
	}
	/**
	 * All social media array
	 *
	 * @return array
	 */
	public function esas_social_bunch() {

		$asas_social_array = array(
			'facebook' => array(
				'name'        => 'Facebook',
				'titleText'   => esc_html__( 'Share this on ', 'easy-select-and-share' ) . 'Facebook',
				'url'         => 'https://www.facebook.com/dialog/share?app_id={app_id}&quote={excerpt}&href={url}',
				'support32px' => 1,
				'icon'        => 'fab fa-facebook-f',
			),
			'twitter'  => array(
				'name'        => 'Twitter',
				'titleText'   => esc_html__( 'Tweet this !', 'easy-select-and-share' ) . '',
				'url'         => 'https://twitter.com/intent/tweet?url={url}&text={excerpt}&via={twitter-username}&original_referer={url}',
				'support32px' => 1,
				'icon'        => 'fab fa-x-twitter',
			),
			'linkedin' => array(
				'name'        => 'LinkedIn',
				'titleText'   => esc_html__( 'Share this on ', 'easy-select-and-share' ) . 'LinkedIn',
				'url'         => 'http://www.linkedin.com/shareArticle?mini=true&url={url}&title={title}&source={blogname}&summary={excerpt}&text={text}',
				'support32px' => 1,
				'icon'        => 'fab fa-linkedin-in',
			),
		);
		return $asas_social_array;
	}

}

