<?php
/**
 * Class for Easy Select and Share
 *
 * @version 1.0
 * @package Easy Select and Share
 */

/**
 * Easy Select and Share plugin
 */
class EasySelectandShare {

	/**
	 * Easy Select and Share admin edit
	 *
	 * @var string
	 */
	public $esas_admin_edit = null;

	/**
	 * Current Filter
	 *
	 * @var string
	 */
	public $is_used = '';

	/**
	 * Current post
	 *
	 * @var string
	 */
	public $cur_post = '';

	/**
	 * Inital Setup
	 */
	public function __construct() {
		add_action( 'wp_head', array( $this, 'esas_enqueue_header_scripts' ), 9 );
		add_action( 'wp_enqueue_scripts', array( $this, 'esas_enqueue_header_styles' ), 11 );
		add_action( 'admin_enqueue_scripts', array( $this, 'esas_admin_scripts' ) );
		add_action( 'plugins_loaded', array( &$this, 'esas_load_language_files' ) );
		add_action( 'admin_menu', array( $this, 'esas_plugin_create_menu' ) );
		add_filter( 'template_redirect', array( $this, 'esas_filters' ) );
		add_action( 'wp_head', array( $this, 'esas_set_ajaxurl' ) );
		add_action( 'wp_head', array( $this, 'esas_front_dynamic_style' ) );
		add_action( 'wp_ajax_esas_get_category_by_posttype', array( $this, 'esas_get_category_by_posttype' ) );
		add_action( 'wp_ajax_esas_set_order', array( $this, 'esas_set_order' ) );
		add_filter( 'post_class', array( $this, 'esas_add_custom_post_class' ) );
		add_action( 'current_screen', array( $this, 'easy_select_and_share_admin_footer' ) );
		add_action( 'plugins_loaded', array( &$this, 'esas_latest_news_solwin_feed' ) );
		add_action( 'wp_ajax_reset_asas_settings', array( &$this, 'esas_reset_default' ) );
		add_action( 'wp_ajax_nopriv_reset_asas_settings', array( &$this, 'esas_reset_default' ) );
		add_action( 'wp_ajax_esas_append_custom_share_icon', array( &$this, 'esas_append_custom_share_icon' ) );
		add_action( 'wp_ajax_nopriv_esas_append_custom_share_icon', array( &$this, 'esas_append_custom_share_icon' ) );
		add_action( 'wp_ajax_submit_asas_log', array( &$this, 'esas_insert_log' ) );
		add_action( 'wp_ajax_nopriv_submit_asas_log', array( &$this, 'esas_insert_log' ) );
		add_action( 'wp_ajax_nopriv_get_asas_log_posts', array( $this, 'esas_get_log_posts' ) );
		add_action( 'wp_ajax_get_asas_log_posts', array( $this, 'esas_get_log_posts' ) );
		add_action( 'wp_footer', array( $this, 'esas_footer_by_class_content' ) );
		if ( class_exists( 'ESASAdminEdit' ) ) {
			$this->esas_admin_edit = new ESASAdminEdit();
		}
	}

	/**
	 * Easy Select and Share filters
	 *
	 * @return void
	 */
	public function esas_filters() {
		$is_singular = is_singular();
		$is_singular = apply_filters( 'asas_is_singular', $is_singular );
		if ( $is_singular ) {
			add_filter( 'the_content', array( $this, 'esas_push_hidden_post_data' ), 100 );
		}
	}

	/**
	 * Admin ajax url
	 *
	 * @return void
	 */
	public function esas_set_ajaxurl() {
		?>
		<script type="text/javascript">
			var ajaxurl = '<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>';
		</script>
		<?php
	}

	/**
	 * Register textdomain
	 *
	 * @return void
	 */
	public function esas_load_language_files() {
		load_plugin_textdomain( 'easy-select-and-share', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Register admin side script
	 *
	 * @return void
	 */
	public function esas_admin_scripts() {
		if ( isset( $_GET['page'] ) && 'easy_select_and_share' === $_GET['page'] ) {
			wp_enqueue_style( 'esas-fontawesome', ESAS_PLUGIN_URL . 'admin/css/font-awesome.min.css', array(), '6.5.1' );
			wp_enqueue_style( 'esas-colorpicker-alpha', ESAS_PLUGIN_URL . 'admin/css/alpha-color-picker.css', array(), '1.0' );
			wp_enqueue_style( 'select2', ESAS_PLUGIN_URL . 'admin/css/select2.css', array(), '1.0' );
			wp_enqueue_style( 'wp-jquery-ui-dialog' );
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_style( 'esas-grid', ESAS_PLUGIN_URL . 'admin/css/sas-grid-style.css', array(), '1.0' );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'select2', ESAS_PLUGIN_URL . 'admin/js/select2.js', array( 'jquery' ), '1.0', true );
			wp_enqueue_script( 'esas-html-sortable', ESAS_PLUGIN_URL . 'admin/js/html.sortable.js', array( 'jquery' ), '1.0', true );
			wp_enqueue_script( 'select2-sortable', ESAS_PLUGIN_URL . 'admin/js/select2.sortable.js', array( 'jquery' ), '1.0', true );
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_script( 'esas-wp-color-picker-alpha', ESAS_PLUGIN_URL . 'admin/js/alpha-color-picker.js', array( 'jquery', 'wp-color-picker', 'wpColorPickerL10n' ), '1.0', true );
			wp_enqueue_script( 'jquery-ui-core' );
			wp_enqueue_script( 'jquery-ui-dialog' );
			wp_enqueue_script( 'esas-admin-script', ESAS_PLUGIN_URL . 'admin/js/admin_script.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

			wp_localize_script(
				'esas-admin-script',
				'esasadminObj',
				array(
					'loading'              => esc_html__( 'Loading...', 'easy-select-and-share' ),
					'no_post_type_found'   => esc_html__( 'No post type found', 'easy-select-and-share' ),
					'no_share_with_found'  => esc_html__( 'No share with found', 'easy-select-and-share' ),
					'no_category_found'    => esc_html__( 'No category found', 'easy-select-and-share' ),
					'share_image_empty'    => esc_html__( 'Share Image is empty. Please fill the empty fields.', 'easy-select-and-share' ),
					'share_icon_empty'     => esc_html__( 'Share Icon is empty. Please fill the empty fields.', 'easy-select-and-share' ),
					'layout_preview'       => esc_html__( 'Preview', 'easy-select-and-share' ),
					'close'                => esc_html__( 'Select', 'easy-select-and-share' ),
					'remove_share_link'    => esc_html__( 'Are you sure to remove this share link?', 'easy-select-and-share' ),
					'choose_preset_layout' => esc_html__( 'Choose Preset Layout', 'easy-select-and-share' ),
					'esas_nonce'           => wp_create_nonce( 'esas_nonce_ajax' ),
				)
			);
		}
		wp_enqueue_style( 'esas-admin-style', ESAS_PLUGIN_URL . 'admin/css/admin_style.css', array(), '1.0' );
	}

	/**
	 * Register header script
	 *
	 * @return void
	 */
	public function esas_enqueue_header_scripts() {
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'esas-esassocialshare', ESAS_PLUGIN_URL . 'asset/js/esassocialShare.js', array( 'jquery' ), '0.1', true );
		wp_localize_script(
			'esas-esassocialshare',
			'esasObj',
			array(
				'esas_front_nonce' => wp_create_nonce( 'esas_front_nonce_ajax' ),
			)
		);
		$options                   = self::esas_get_option();
		$supported_posttypes       = isset( $options['asas_supported_posttype'] ) ? $options['asas_supported_posttype'] : array( 'post' );
		$supported_category        = isset( $options['asas_supported_category'] ) ? $options['asas_supported_category'] : array( -99 );
		$asas_show_widget_position = isset( $options['asas_show_widget_position'] ) ? $options['asas_show_widget_position'] : 'beside_selected_text';
		if ( 'in_popup' === $asas_show_widget_position ) {
			$asas_widget_in_popup = 1;
		} else {
			$asas_widget_in_popup = 0;
		}
		$posty_cat_merge = array_merge( $supported_posttypes, $supported_category );
		$posty_cat_merge = implode( ',', $posty_cat_merge );

		wp_localize_script(
			'esas-esassocialshare',
			'sasoptnObj',
			array(
				'posty_cat_merge'      => $posty_cat_merge,
				'asas_widget_in_popup' => $asas_show_widget_position,
			)
		);
	}

	/**
	 * Register header style
	 *
	 * @return void
	 */
	public function esas_enqueue_header_styles() {
		wp_register_style( 'esas-fontawesome', ESAS_PLUGIN_URL . 'admin/css/font-awesome.min.css', array(), '6.5.1' );
		wp_enqueue_style( 'esas-fontawesome' );
		wp_register_style( 'esas-client-style', ESAS_PLUGIN_URL . 'asset/css/clients_style.css', false, '0.1' );
		wp_enqueue_style( 'esas-client-style' );
	}

	/**
	 * Create Menu Page
	 *
	 * @return void
	 */
	public function esas_plugin_create_menu() {
		add_menu_page( esc_html__( 'Easy Select and Share', 'easy-select-and-share' ), esc_html__( 'Easy Select and Share', 'easy-select-and-share' ), 'administrator', 'easy_select_and_share', array( $this->esas_admin_edit, 'esas_plugin_settings_page' ), 'dashicons-share' );
	}

	/**
	 * Dynamic Css
	 *
	 * @return void
	 */
	public function esas_front_dynamic_style() {
		$options                        = self::esas_get_option();
		$title_color                    = isset( $options['asas_title_color'] ) ? $options['asas_title_color'] : '#333';
		$custom_css                     = isset( $options['asas_custom_css'] ) ? $options['asas_custom_css'] : '';
		$asas_widget_background         = isset( $options['asas_widget_background'] ) ? $options['asas_widget_background'] : '#fff';
		$asas_widget_border_color       = isset( $options['asas_widget_border_color'] ) ? $options['asas_widget_border_color'] : '#e2e2e2';
		$asas_share_widget_border_width = isset( $options['asas_share_widget_border_width'] ) ? $options['asas_share_widget_border_width'] : '0';
		$asas_share_widget_border_type  = isset( $options['asas_share_widget_border_type'] ) ? $options['asas_share_widget_border_type'] : 'solid';
		$asas_widget_border_radius      = isset( $options['asas_widget_border_radius'] ) ? $options['asas_widget_border_radius'] : '5';
		$asas_show_widget_box_shadow    = isset( $options['asas_show_widget_box_shadow'] ) ? $options['asas_show_widget_box_shadow'] : '0';
		$asas_widget_box_shadow_color   = isset( $options['asas_widget_box_shadow_color'] ) ? $options['asas_widget_box_shadow_color'] : '';
		$asas_title_background          = isset( $options['asas_title_background'] ) ? $options['asas_title_background'] : '#fff';
		$asas_show_box_shadow           = isset( $options['asas_show_box_shadow'] ) ? $options['asas_show_box_shadow'] : '0';
		$asas_box_shadow_color          = isset( $options['asas_box_shadow_color'] ) ? $options['asas_box_shadow_color'] : '';
		$asas_share_button_type         = isset( $options['asas_share_button_type'] ) ? $options['asas_share_button_type'] : 'icon';
		$asas_box_border_radius         = isset( $options['asas_box_border_radius'] ) ? $options['asas_box_border_radius'] : '5';
		$asas_box_bgcolor               = isset( $options['asas_box_bgcolor'] ) ? $options['asas_box_bgcolor'] : '';
		$asas_box_border_width          = isset( $options['asas_box_border_width'] ) ? $options['asas_box_border_width'] : '0';
		$asas_share_box_border_type     = isset( $options['asas_share_box_border_type'] ) ? $options['asas_share_box_border_type'] : 'solid';
		$asas_box_border_color          = isset( $options['asas_box_border_color'] ) ? $options['asas_box_border_color'] : '';
		$asas_icon_text_color           = isset( $options['asas_icon_text_color'] ) ? $options['asas_icon_text_color'] : '#fff';
		$asas_icon_font_size            = isset( $options['asas_icon_font_size'] ) ? $options['asas_icon_font_size'] : '16';
		$asas_icon_bgcolor              = isset( $options['asas_icon_bgcolor'] ) ? $options['asas_icon_bgcolor'] : '';
		$asas_icon_line_height          = isset( $options['asas_icon_line_height'] ) ? $options['asas_icon_line_height'] : '16';
		$asas_icon_padding_top          = isset( $options['asas_icon_padding_top'] ) ? $options['asas_icon_padding_top'] : '10';
		$asas_icon_padding_bottom       = isset( $options['asas_icon_padding_bottom'] ) ? $options['asas_icon_padding_bottom'] : '10';
		$asas_icon_padding_left         = isset( $options['asas_icon_padding_left'] ) ? $options['asas_icon_padding_left'] : '10';
		$asas_icon_padding_right        = isset( $options['asas_icon_padding_right'] ) ? $options['asas_icon_padding_right'] : '10';
		$asas_icon_border_top_width     = isset( $options['asas_icon_border_width'] ) ? $options['asas_icon_border_width'] : '0';
		$asas_icon_border_top_type      = isset( $options['asas_icon_border_type'] ) ? $options['asas_icon_border_type'] : 'solid';
		$asas_icon_border_top_color     = isset( $options['asas_icon_border_color'] ) ? $options['asas_icon_border_color'] : '';
		$asas_icon_border_bottom_width  = isset( $options['asas_icon_border_bottom_width'] ) ? $options['asas_icon_border_bottom_width'] : '0';
		$asas_icon_border_bottom_type   = isset( $options['asas_icon_border_bottom_type'] ) ? $options['asas_icon_border_bottom_type'] : 'solid';
		$asas_icon_border_bottom_color  = isset( $options['asas_icon_border_bottom_color'] ) ? $options['asas_icon_border_bottom_color'] : '';
		$asas_icon_border_left_width    = isset( $options['asas_icon_border_left_width'] ) ? $options['asas_icon_border_left_width'] : '0';
		$asas_icon_border_left_type     = isset( $options['asas_icon_border_left_type'] ) ? $options['asas_icon_border_left_type'] : 'solid';
		$asas_icon_border_left_color    = isset( $options['asas_icon_border_left_color'] ) ? $options['asas_icon_border_left_color'] : '';
		$asas_icon_border_right_width   = isset( $options['asas_icon_border_right_width'] ) ? $options['asas_icon_border_right_width'] : '0';
		$asas_icon_border_right_type    = isset( $options['asas_icon_border_right_type'] ) ? $options['asas_icon_border_right_type'] : 'solid';
		$asas_icon_border_right_color   = isset( $options['asas_icon_border_right_color'] ) ? $options['asas_icon_border_right_color'] : '';
		$asas_icon_border_radius        = isset( $options['asas_icon_border_radius'] ) ? $options['asas_icon_border_radius'] : '15';
		$asas_box_padding_top           = isset( $options['asas_box_padding_top'] ) ? $options['asas_box_padding_top'] : '0';
		$asas_box_padding_right         = isset( $options['asas_box_padding_right'] ) ? $options['asas_box_padding_right'] : '0';
		$asas_box_padding_bottom        = isset( $options['asas_box_padding_bottom'] ) ? $options['asas_box_padding_bottom'] : '0';
		$asas_box_padding_left          = isset( $options['asas_box_padding_left'] ) ? $options['asas_box_padding_left'] : '0';
		$asas_text_font_size            = isset( $options['asas_text_font_size'] ) ? $options['asas_text_font_size'] : '14';
		$asas_text_color                = isset( $options['asas_text_color'] ) ? $options['asas_text_color'] : '#fff';
		$asas_widget_border_rad_type    = ( isset( $options['asas_widget_border_rad_type'] ) && '' !== $options['asas_widget_border_rad_type'] ) ? $options['asas_widget_border_rad_type'] : '%';
		$asas_box_border_rad_type       = ( isset( $options['asas_box_border_rad_type'] ) && '' !== $options['asas_box_border_rad_type'] ) ? $options['asas_box_border_rad_type'] : '%';
		$asas_icon_border_rad_type      = ( isset( $options['asas_icon_border_rad_type'] ) && '' !== $options['asas_icon_border_rad_type'] ) ? $options['asas_icon_border_rad_type'] : '%';
		$asas_widget_width              = ( isset( $options['asas_widget_width'] ) && '' !== $options['asas_widget_width'] ) ? $options['asas_widget_width'] : '';
		$asas_widget_width_type         = ( isset( $options['asas_widget_width_type'] ) && '' !== $options['asas_widget_width_type'] ) ? $options['asas_widget_width_type'] : '%';
		$asas_text_padding_top          = isset( $options['asas_text_padding_top'] ) ? $options['asas_text_padding_top'] : '0';
		$asas_text_padding_right        = isset( $options['asas_text_padding_right'] ) ? $options['asas_text_padding_right'] : '0';
		$asas_text_padding_bottom       = isset( $options['asas_text_padding_bottom'] ) ? $options['asas_text_padding_bottom'] : '0';
		$asas_text_padding_left         = isset( $options['asas_text_padding_left'] ) ? $options['asas_text_padding_left'] : '0';
		$asas_display_close_button      = isset( $options['asas_display_close_button'] ) ? $options['asas_display_close_button'] : '1';
		$asas_widget_title              = isset( $options['asas_widget_title'] ) ? $options['asas_widget_title'] : '';
		$asas_show_widget_position      = isset( $options['asas_show_widget_position'] ) ? $options['asas_show_widget_position'] : 'beside_selected_text';
		?>
		<style>
			.shareit_by_class::after,
			.shareit_by_class::before,
			.shareit::after,
			.shareit::before {
				<?php
				if ( '' !== $asas_widget_background ) {
					?>
					border-bottom-color: <?php echo esc_attr( $asas_widget_background ); ?>;
					<?php
				}
				?>
			}
			.shareit_by_class,
			.shareit {
				<?php
				if ( '' !== $asas_widget_background ) {
					?>
					background-color: <?php echo esc_attr( $asas_widget_background ); ?>;
					<?php
				}
				if ( '' !== $asas_widget_border_color && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
					?>
					border-color: <?php echo esc_attr( $asas_widget_border_color ); ?>;
					<?php
				}
				if ( '' !== $asas_share_widget_border_width && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
					?>
					border-width: <?php echo esc_attr( $asas_share_widget_border_width ) . 'px'; ?>;
					<?php
				}
				if ( '' !== $asas_share_widget_border_type && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
					?>
					border-style: <?php echo esc_attr( $asas_share_widget_border_type ); ?>;
					<?php
				}
				if ( '' !== $asas_widget_border_radius && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
					?>
					border-radius: <?php echo esc_attr( $asas_widget_border_radius ) . esc_html( $asas_widget_border_rad_type ); ?>;
					<?php
				}
				if ( '0' !== $asas_show_widget_box_shadow && '' !== $asas_widget_box_shadow_color && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
					?>
					box-shadow: 1px 2px 6px 4px <?php echo esc_attr( $asas_widget_box_shadow_color ); ?>;
					<?php
				}
				if ( '1' !== $asas_display_close_button && '' === $asas_widget_title ) {
					?>
					padding: 15px 0;
					<?php
				}
				if ( '' !== $asas_widget_width && '0' !== $asas_widget_width ) {
					?>
					width : <?php echo esc_attr( $asas_widget_width ) . esc_html( $asas_widget_width_type ); ?>;
					<?php
				}
				?>
			}
			<?php
			if ( '' !== $asas_widget_background ) {
				?>
				.shareit_by_class.before_content .share-icon-wrapper,
				.shareit_by_class.after_content .share-icon-wrapper,
				.shareit.before_content .share-icon-wrapper,
				.shareit.after_content .share-icon-wrapper {
					padding-left: 25px;
					padding-right: 25px;
					padding-bottom: 20px;
				}
				<?php
			}
			if ( 1 == $asas_display_close_button && '' === $asas_widget_title ) {
				?>
				.share-this-popup-top {
					margin-bottom: 20px; 
				}
				.popup-close-btn-by-class,
				.popup-close-btn {
					top: -10px;
				} 
				<?php
			}
			if ( '0' !== $asas_show_box_shadow && '' !== $asas_box_shadow_color ) {
				?>
				.shareit_by_class .share-icon-wrapper.asas_box_shadow_enable .share-icon-item,
				.shareit .share-icon-wrapper.asas_box_shadow_enable .share-icon-item {
					box-shadow: 5px 5px 6px 2px <?php echo esc_attr( $asas_box_shadow_color ); ?>;
				} 
				<?php
			}
			?>
			.share-note {
				<?php if ( '' !== $asas_widget_background ) { ?>
					background-color: <?php echo esc_attr( $asas_widget_background ); ?>;
					<?php
				}
				if ( '' !== $asas_widget_border_color ) {
					?>
					border-color: <?php echo esc_attr( $asas_widget_border_color ); ?>;
				<?php } ?>
			}
			<?php
			if ( '' !== $title_color ) {
				?>
				.share-it-title strong {
					color: <?php echo esc_attr( $title_color ); ?> !important;
				}
				<?php
			}
			?>
			.share-it-title {
				<?php if ( '' !== $asas_title_background ) { ?>
					background-color: <?php echo esc_attr( $asas_title_background ); ?>;
				<?php } ?>
			}
			<?php
			if ( 'img' !== $asas_share_button_type ) {
				?>
				.shareit_by_class .share-icon-wrapper .share-icon-item,
				.shareit .share-icon-wrapper .share-icon-item {
					<?php
					if ( '' !== $asas_box_border_radius ) {
						?>
						border-radius: <?php echo esc_attr( $asas_box_border_radius ) . esc_html( $asas_box_border_rad_type ); ?>;
						<?php
					}
					if ( '' !== $asas_box_bgcolor ) {
						?>
						background-color: <?php echo esc_attr( $asas_box_bgcolor ); ?>;
						<?php
					}
					if ( '' !== $asas_box_border_width ) {
						?>
						border-width: <?php echo esc_attr( $asas_box_border_width ) . 'px '; ?>;
						<?php
					}
					if ( '' !== $asas_share_box_border_type ) {
						?>
						border-style: <?php echo esc_attr( $asas_share_box_border_type ); ?>;
						<?php
					}
					if ( '' !== $asas_box_border_color ) {
						?>
						border-color: <?php echo esc_attr( $asas_box_border_color ); ?>;
						<?php
					}
					?>
				}
				.shareit_by_class .share-icon-wrapper .share-icon-item .asas_share_btn i,
				.shareit .share-icon-wrapper .share-icon-item .asas_share_btn i {
					<?php
					if ( '' !== $asas_icon_text_color ) {
						?>
						color: <?php echo esc_attr( $asas_icon_text_color ); ?>; 
						<?php
					}
					if ( '' !== $asas_icon_font_size && '0' !== $asas_icon_font_size ) {
						?>
						font-size: <?php echo esc_attr( $asas_icon_font_size ) . 'px '; ?>;
						<?php
					}
					if ( '' !== $asas_icon_bgcolor ) {
						?>
						background-color: <?php echo esc_attr( $asas_icon_bgcolor ); ?>; 
						<?php
					}
					if ( '' !== $asas_icon_line_height && '0' !== $asas_icon_line_height ) {
						?>
						line-height: <?php echo esc_attr( $asas_icon_line_height ) . 'px '; ?>;
						<?php
					}
					if ( isset( $asas_icon_padding_top ) && '' !== $asas_icon_padding_top ) {
						?>
						padding-top: <?php echo esc_attr( $asas_icon_padding_top ) . 'px '; ?>;
						<?php
					}
					if ( isset( $asas_icon_padding_bottom ) && '' !== $asas_icon_padding_bottom ) {
						?>
						padding-bottom: <?php echo esc_attr( $asas_icon_padding_bottom ) . 'px '; ?>;
						<?php
					}
					if ( isset( $asas_icon_padding_left ) && '' !== $asas_icon_padding_left ) {
						?>
						padding-left: <?php echo esc_attr( $asas_icon_padding_left ) . 'px '; ?>;
						<?php
					}
					if ( isset( $asas_icon_padding_right ) && '' !== $asas_icon_padding_right ) {
						?>
						padding-right: <?php echo esc_attr( $asas_icon_padding_right ) . 'px '; ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_top_width ) {
						?>
						border-top-width: <?php echo esc_attr( $asas_icon_border_top_width ) . 'px'; ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_top_type ) {
						?>
						border-top-style: <?php echo esc_attr( $asas_icon_border_top_type ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_top_color ) {
						?>
						border-top-color: <?php echo esc_attr( $asas_icon_border_top_color ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_bottom_width ) {
						?>
						border-bottom-width: <?php echo esc_attr( $asas_icon_border_bottom_width ) . 'px'; ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_bottom_type ) {
						?>
						border-bottom-style: <?php echo esc_attr( $asas_icon_border_bottom_type ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_bottom_color ) {
						?>
						border-bottom-color: <?php echo esc_attr( $asas_icon_border_bottom_color ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_left_width ) {
						?>
						border-left-width: <?php echo esc_attr( $asas_icon_border_left_width ) . 'px'; ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_left_type ) {
						?>
						border-left-style: <?php echo esc_attr( $asas_icon_border_left_type ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_left_color ) {
						?>
						border-left-color: <?php echo esc_attr( $asas_icon_border_left_color ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_right_width ) {
						?>
						border-right-width: <?php echo esc_attr( $asas_icon_border_right_width ) . 'px'; ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_right_type ) {
						?>
						border-right-style: <?php echo esc_attr( $asas_icon_border_right_type ); ?>;
						<?php
					}
					if ( '' !== $asas_icon_border_right_color ) {
						?>
						border-right-color: <?php echo esc_attr( $asas_icon_border_right_color ); ?>;
						<?php
					}
					if ( isset( $asas_icon_border_radius ) && isset( $asas_icon_border_rad_type ) && '' !== $asas_icon_border_rad_type && '' !== $asas_icon_border_radius ) {
						?>
						border-radius: <?php echo esc_attr( $asas_icon_border_radius ) . esc_html( $asas_icon_border_rad_type ); ?>;
						<?php
					}
					?>
				}
				.shareit_by_class .share-icon-wrapper .share-icon-item .asas_share_btn,
				.shareit .share-icon-wrapper .share-icon-item .asas_share_btn {
					<?php
					if ( '' !== $asas_icon_line_height && '0' !== $asas_icon_line_height ) {
						?>
						line-height: <?php echo esc_attr( $asas_icon_line_height ) . 'px '; ?>;
						<?php
					}
					if ( '' !== $asas_icon_font_size && '0' !== $asas_icon_font_size ) {
						?>
						font-size: <?php echo esc_attr( $asas_icon_font_size ) . 'px '; ?>;
						<?php
					}
					if ( '' !== $asas_icon_text_color ) {
						?>
						color: <?php echo esc_attr( $asas_icon_text_color ); ?>; 
						<?php
					}
					if ( $asas_box_padding_top > 0 || $asas_box_padding_right > 0 || $asas_box_padding_bottom > 0 || $asas_box_padding_left > 0 ) {
						?>
						padding: 
						<?php
						echo esc_attr( $asas_box_padding_top ) . 'px ' . esc_attr( $asas_box_padding_right ) . 'px ' . esc_attr( $asas_box_padding_bottom ) . 'px ' . esc_attr( $asas_box_padding_left ) . 'px ';
					}
					?>
				}
				<?php
			}
			?>
			.share-icon-wrapper .share-icon-item span {
				<?php
				if ( '' !== $asas_text_font_size && '0' !== $asas_text_font_size ) {
					?>
					font-size: <?php echo esc_attr( $asas_text_font_size ) . 'px '; ?>;
					<?php
				}
				if ( '' !== $asas_text_color ) {
					?>
					color: <?php echo esc_attr( $asas_text_color ); ?>; 
					<?php
				}
				if ( $asas_text_padding_top > 0 || $asas_text_padding_right > 0 || $asas_text_padding_bottom > 0 || $asas_text_padding_left > 0 ) {
					?>
					padding-top : <?php echo esc_attr( $asas_text_padding_top ) . 'px '; ?>;
					padding-right : <?php echo esc_attr( $asas_text_padding_right ) . 'px '; ?>;
					padding-bottom : <?php echo esc_attr( $asas_text_padding_bottom ) . 'px '; ?>;
					padding-left : <?php echo esc_attr( $asas_text_padding_left ) . 'px '; ?>;
					<?php
				}
				?>
			}
			<?php
			echo esc_textarea( wp_unslash( $custom_css ) );
			?>
		</style>
		<?php
	}

	/**
	 * Trim post content
	 *
	 * @param string $content Post content.
	 * @param int    $post_id Post id.
	 * @return html
	 */
	public function esas_get_trim_content( $content, $post_id ) {
		global $post;
		$options = self::esas_get_option();
		if ( 'con' === $options['asas_share_text'] && ! empty( $options['asas_excerpt_limit'] ) && $options['asas_excerpt_limit'] > 0 ) {
			$content = wp_trim_words( $content, intval( $options['asas_excerpt_limit'] ), '...' );
		}
		return $content;
	}

	/**
	 * Get the post_thumbnail or first image  of the post
	 *
	 * @param int    $post_id Post id.
	 * @param string $post_cnt Post content.
	 */
	public function esas_get_post_thumbnail_url( $post_id, $post_cnt = '' ) {
		$args        = array(
			'numberposts'    => 1,
			'order'          => 'ASC',
			'post_mime_type' => 'image',
			'post_parent'    => $post_id,
			'post_status'    => null,
			'post_type'      => 'attachment',
		);
		$attachments = get_children( $args );
		// Check for image attachments in posts.
		if ( $attachments ) {
			foreach ( $attachments as $attachment ) {
				return $attachment->guid;
			}
		} else {
			// If no image attachements, then get the full post thumbnail.
			if ( function_exists( 'has_post_thumbnail' ) && has_post_thumbnail( $post_id ) ) {
				$image_id  = get_post_thumbnail_id( $post_id );
				$image_url = wp_get_attachment_image_src( $image_id, 'large' );
				return $image_url[0];
			} else {
				// Or else get the first image present in the post content.
				$output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post_cnt, $matches );

				if ( ! empty( $matches[1] ) ) {
					$first_img = $matches [1] [0];
					return $first_img;
				}
			}
		}
	}

	/**
	 * Get category by post type
	 *
	 * @return void
	 */
	public function esas_get_category_by_posttype() {
		$esas_nonce = isset( $_REQUEST['esas_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['esas_nonce'] ) ) : '';
		if ( ! empty( $_REQUEST['postType'] ) && wp_verify_nonce( $esas_nonce, 'esas_nonce_ajax' ) ) {
			$post_types        = array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['postType'] ) );
			$exlude_taxonomys  = array( 'post_format', 'product_type', 'product_tag', 'product_shipping_class' );
			$options           = self::esas_get_option();
			$selected_cats_arr = ( isset( $options['asas_supported_category'] ) ) ? $options['asas_supported_category'] : array();
			$cat_arr           = array();
			$categories        = array();
			$seloption         = array();
			if ( is_array( $post_types ) ) {
				foreach ( $post_types as $posttype ) :
					$taxonomy_objects = get_object_taxonomies( $posttype, 'names' );
					foreach ( $taxonomy_objects as $taxonomy ) :
						if ( ! in_array( $taxonomy, $exlude_taxonomys, true ) ) {
							$categories[] = get_categories( 'taxonomy=' . $taxonomy );
						}
					endforeach;
				endforeach;
			}
			if ( is_array( $categories ) ) {
				foreach ( $categories as $key => $cats ) :
					foreach ( $cats as $cat ) :
						$cat_arr[] = $cat->name;
						if ( in_array( $cat->term_id, $selected_cats_arr, true ) ) {
							$seloption[] = '<option value="' . $cat->term_id . '" selected="true" >' . $cat->name . '</option>';
						} else {
							$seloption[] = '<option value="' . $cat->term_id . '">' . $cat->name . '</option>';
						}
					endforeach;
				endforeach;
			}
			echo implode(
				'',
				array_map(
					'wp_kses',
					$seloption,
					array(
						'option' => array(
							'value' => true,
						),
					)
				)
			);
		}
		wp_die();
	}

	/**
	 * Save order in database.
	 *
	 * @return void
	 */
	public function esas_set_order() {
		$esas_nonce = isset( $_REQUEST['esas_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['esas_nonce'] ) ) : '';
		if ( ! empty( $_REQUEST['order'] ) && wp_verify_nonce( $esas_nonce, 'esas_nonce_ajax' ) ) {
			$asas_social_order = sanitize_text_field( wp_unslash( $_REQUEST['order'] ) );
			update_option( 'asas_social_order', $asas_social_order );
		}
		wp_die();
	}

	/**
	 * Add dynamic post class.
	 *
	 * @param string $classes Classes.
	 * @return array
	 */
	public function esas_add_custom_post_class( $classes ) {
		global $post;
		$classes[] = 'asas_shareit'; // Add your class however its generated here.
		return $classes;
	}

	/**
	 * Push hidden Post Data
	 *
	 * @param string $content content.
	 * @return html
	 */
	public function esas_push_hidden_post_data( $content = '' ) {
		$out = '';
		global $post;
		$current_filter = current_filter();
		$cur_post       = $post->ID;
		$asas_add_soc   = 'no';
		if ( ( '' === $this->is_used || $this->is_used === $current_filter ) || ( '' === $this->cur_post || $this->cur_post !== $cur_post ) ) {
			ob_start();
			global $post;
			$current_post_type         = get_post_type( $cur_post );
			$options                   = self::esas_get_option();
			$supported_category        = isset( $options['asas_supported_category'] ) ? $options['asas_supported_category'] : array();
			$supported_posttypes       = isset( $options['asas_supported_posttype'] ) ? $options['asas_supported_posttype'] : array( 'post' );
			$asas_show_widget_position = isset( $options['asas_show_widget_position'] ) ? $options['asas_show_widget_position'] : 'beside_selected_text';
			$cat_str                   = '';
			if ( ! empty( $supported_posttypes ) ) {
				if ( in_array( $current_post_type, $supported_posttypes, true ) ) {
					if ( ! empty( $supported_category ) ) {
						$current_post_terms   = array();
						$supported_post_terms = array();
						$all_post_terms       = array();
						$taxonomy_objects     = get_object_taxonomies( $current_post_type, 'names' );
						if ( $taxonomy_objects ) {
							$supported_cats_empty = 'yes';
							foreach ( $taxonomy_objects as $taxonomy ) {
								$current_post_terms[ $taxonomy ] = array();
								$wp_get_post_terms               = wp_get_post_terms( $cur_post, $taxonomy, array( 'fields' => 'ids' ) );
								if ( ! empty( $wp_get_post_terms ) ) {
									foreach ( $wp_get_post_terms as $wp_get_post_term ) {
										$current_post_terms[ $taxonomy ][] = $wp_get_post_term;
									}
								}
								$supported_post_terms[ $taxonomy ] = array();
								$all_post_terms[ $taxonomy ]       = array();
								$get_categories                    = get_categories( 'taxonomy=' . $taxonomy );
								if ( ! empty( $get_categories ) ) {
									foreach ( $get_categories as $get_category ) {
										$all_post_terms[ $taxonomy ][] = $get_category->term_id;
										if ( in_array( $get_category->term_id, $supported_category, true ) ) {
											$supported_cats_empty                = 'no';
											$supported_post_terms[ $taxonomy ][] = $get_category->term_id;
										}
									}
								}
							}

							if ( 'yes' === $supported_cats_empty ) {
								$asas_add_soc = 'yes';
							}
						}
						if ( ! empty( $current_post_terms ) ) {
							foreach ( $current_post_terms as $cur_tax_name => $cur_tax_terms ) {
								$sup_tax_terms = $supported_post_terms[ $cur_tax_name ];
								foreach ( $cur_tax_terms as $cur_tax_term ) {
									if ( ! empty( $sup_tax_terms ) ) {
										if ( in_array( $cur_tax_term, $sup_tax_terms, true ) ) {
											$asas_add_soc = 'yes';
										}
									}
								}
							}
						} else {
							$asas_add_soc = 'yes';
						}
					} else {
						$asas_add_soc = 'yes';
					}
				} else {
					$asas_add_soc = 'no';
				}
			} else {
				$asas_add_soc = 'no';
			}
			if ( 'yes' === $asas_add_soc ) {
				$selected      = isset( $options['share_select'] ) ? $options['share_select'] : array( 'twitter', 'linkedin' );
				$build_options = $this->esas_admin_edit->esas_social_bunch();

				$extra_class     = isset( $options['asas_widget_extra_class'] ) ? $options['asas_widget_extra_class'] : '';
				$rss             = ( empty( $options['rssurl'] ) ) ? get_bloginfo( 'rss_url' ) : $options['rssurl'];
				$text_to_share   = ( ! empty( $options['asas_share_text'] ) ) ? $options['asas_share_text'] : 'sel';
				$blogname        = rawurlencode( get_bloginfo( 'name' ) . ' - ' . get_bloginfo( 'description' ) );
				$email           = get_bloginfo( 'admin_email' );
				$twitterusername = ( empty( $options['twitter_username'] ) ) ? '' : $options['twitter_username'];
				$facebook_appid  = ( empty( $options['facebook_appid'] ) ) ? '' : $options['facebook_appid'];

				$to_be_replaced            = array();
				$asas_show_box_shadow      = isset( $options['asas_show_box_shadow'] ) ? $options['asas_show_box_shadow'] : '1';
				$asas_share_button_type    = isset( $options['asas_share_button_type'] ) ? $options['asas_share_button_type'] : 'icon';
				$asas_image_layout         = isset( $options['asas_image_layout'] ) ? $options['asas_image_layout'] : 'asas_image_layout_1';
				$esc_layout_preset         = isset( $options['esc_layout_preset'] ) ? $options['esc_layout_preset'] : 'esc_layout_preset_5';
				$asas_widget_title         = isset( $options['asas_widget_title'] ) ? $options['asas_widget_title'] : '';
				$asas_share_icon_position  = isset( $options['asas_share_icon_position'] ) ? $options['asas_share_icon_position'] : 'left';
				$padding_left              = ( isset( $options['asas_icon_padding_left'] ) && '' !== $options['asas_icon_padding_left'] ) ? $options['asas_icon_padding_left'] : '10';
				$padding_right             = ( isset( $options['asas_icon_padding_right'] ) && '' !== $options['asas_icon_padding_right'] ) ? $options['asas_icon_padding_right'] : '10';
				$asas_icon_font_size       = ( isset( $options['asas_icon_font_size'] ) && '' !== $options['asas_icon_font_size'] ) ? $options['asas_icon_font_size'] : '16';
				$asas_show_box_shadow      = isset( $options['asas_show_box_shadow'] ) ? $options['asas_show_box_shadow'] : '0';
				$asas_display_close_button = isset( $options['asas_display_close_button'] ) ? $options['asas_display_close_button'] : '1';

				$post_id      = $post->ID;
				$post_url     = get_permalink( $post_id );
				$post_title   = get_the_title( $post_id );
				$post_content = $this->esas_get_trim_content( get_post( $post_id )->post_content, $post_id );
				if ( has_excerpt( $post_id ) ) {
					$post_content = get_the_excerpt( $post_id );
				} else {
					$post_content = get_the_content( $post_id );
				}
				$post_content            = wp_strip_all_tags( $post_content );
				$asas_words              = explode( ' ', $post_content );
				$asas_add_soc_word_limit = $options['asas_excerpt_limit'];
				if ( count( $asas_words ) > $asas_add_soc_word_limit ) {
					$post_excerpt = implode( ' ', array_splice( $asas_words, 0, $asas_add_soc_word_limit ) );
				} else {
					$post_excerpt = implode( ' ', $asas_words );
				}
				$post_short_url = $this->esas_get_shorturl( $post_url );
				if ( isset( $options['enable_shortlinks'] ) ) {
					$post_url = wp_get_shortlink( $post_id );
				}
				$post_thumb = $this->esas_get_post_thumbnail_url( $post_id, $post_content );
				?>
				<div class='shareit 
				<?php
				if ( '' !== $asas_show_widget_position ) {
					echo esc_attr( $asas_show_widget_position ) . ' ';
				}
				if ( '' !== $asas_image_layout ) {
					echo esc_attr( $asas_image_layout ) . ' ';
				}
				if ( '' !== $esc_layout_preset ) {
					echo esc_attr( $esc_layout_preset ) . ' ';
				}
				if ( '' !== $asas_share_button_type ) {
					echo 'asas_button_type_' . esc_attr( $asas_share_button_type ) . ' ';
				}
				echo esc_attr( $extra_class );
				?>
					'>
					<div class="shareit_hidden_post_data" style="display: none">
						<input type="hidden" class="shareit_post_id" name="shareit_post_id" value="<?php echo esc_attr( $post->ID ); ?>">
						<input type="hidden" class="shareit_post_type" name="shareit_post_type" value="<?php echo esc_attr( $current_post_type ); ?>">
						<input type="hidden" class="shareit_post_cat" name="shareit_post_cat" value="<?php echo esc_attr( $cat_str ); ?>">
					</div>
					<?php if ( '' !== $asas_widget_title || '1' === $asas_display_close_button ) { ?>
						<div class="share-this-popup-top">
							<?php
							if ( '' !== $asas_widget_title ) :
								?>
								<div class="share-it-title"><strong><?php echo esc_attr( $asas_widget_title ); ?></strong></div>
								<?php
							endif;
							if ( '1' === $asas_display_close_button && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
								?>
								<a class="popup-close-btn" href="javascript:void(0);"></a>
							<?php } ?>
						</div>
					<?php } ?>
					<div class="share-icon-wrapper 
					<?php
					if ( '0' !== $asas_show_box_shadow ) {
						echo 'asas_box_shadow_enable ';
					}
					?>
						">
							<?php
								$asas_social_order = get_option( 'asas_social_order' );
							if ( '' === $asas_social_order ) {
								$asas_social_order = 'twitter, linkedin, facebook';
							}
								$key               = '';
								$asas_social_order = explode( ',', $asas_social_order );
								array_pop( $asas_social_order );
							foreach ( $asas_social_order as $asas_social ) {
								if ( isset( $asas_social ) && '' !== $asas_social ) {
									$asas_social = trim( $asas_social );
									if ( isset( $build_options[ $asas_social ] ) ) {
										$val = $build_options[ $asas_social ];
										$key = $asas_social;
									}
								}
								if ( in_array( trim( $key ), $selected, true ) ) {
									if ( 'before_content' === $asas_show_widget_position || 'after_content' === $asas_show_widget_position ) {
										$replace_with   = array(
											rawurlencode( $post_url ),
											rawurlencode( $post_title ),
											$rss,
											$blogname,
											rawurlencode( $post_excerpt ),
											$post_url,
											$post_title,
											$post_excerpt,
											rawurlencode( $post_excerpt ),
											$email,
											$twitterusername,
											$post_short_url,
											$post_thumb,
											$facebook_appid,
										);
										$to_be_replaced = array(
											'{url}',
											'{title}',
											'{rss-url}',
											'{blogname}',
											'{excerpt}',
											'{de-url}',
											'{de-title}',
											'{de-excerpt}',
											'{text}',
											'{email_address}',
											'{twitter-username}',
											'{s-url}',
											'{image}',
											'{app_id}',
										);
									} else {
										$replace_with   = array(
											rawurlencode( $post_url ),
											rawurlencode( $post_title ),
											$rss,
											$blogname,
											rawurlencode( $post_excerpt ),
											$post_url,
											$post_title,
											$email,
											$twitterusername,
											$post_short_url,
											$post_thumb,
											$facebook_appid,
										);
										$to_be_replaced = array(
											'{url}',
											'{title}',
											'{rss-url}',
											'{blogname}',
											'{excerpt}',
											'{de-url}',
											'{de-title}',
											'{email_address}',
											'{twitter-username}',
											'{s-url}',
											'{image}',
											'{app_id}',
										);
									}
									$bookmark = '';
									if ( 'addtofavorites' === $key ) {
										$bookmark = 'onclick=addBookmark(event);';
									}
									$custom_share = 'false';

									$image = ( isset( $build_options[ $key ]['image'] ) && '' !== $build_options[ $key ]['image'] ) ? $build_options[ $key ]['image'] : '';
									$icon  = ( isset( $build_options[ $key ]['icon'] ) && '' !== $build_options[ $key ]['icon'] ) ? $build_options[ $key ]['icon'] : '';
									if ( 'facebook' === $key && '' === $facebook_appid ) {
										continue;
									}

									if ( 'facebook' === $key || 'linkedin' === $key || 'tumblr' === $key || 'twitter' === $key || 'email' === $key || 'skype' === $key || 'vk' === $key || 'whatsapp' === $key || 'xing' === $key || 'pinterest' === $key || 'blogger' === $key || 'reddit' === $key || 'wikipedia' === $key || 'buffer' === $key ) {
										$class = ( isset( $options[ $key . '_icon' ] ) && '' !== $options[ $key . '_icon' ] ) ? $options[ $key . '_icon' ] : $build_options[ $key ]['icon'];
									} else {
										$custom_share = 'true';
										$class        = $key . ' ' . $icon;
									}

									$height = '40px';
									$width  = '40px';
									$height = $padding_left + $padding_right + $asas_icon_font_size + 5;
									$width  = $padding_left + $padding_right + $asas_icon_font_size + 5;

									$social_link = str_replace( $to_be_replaced, $replace_with, $val['url'] );
									if ( 'icon' === $asas_share_button_type ) {
										?>
									<div class='share-icon-item <?php echo esc_attr( $key ); ?>'><a class='asas_share_btn <?php echo esc_attr( $key ); ?>' rev='<?php echo esc_url( $social_link ); ?>' title='<?php echo esc_html( $val['name'] ); ?>' <?php echo esc_html( $bookmark ); ?> href='javascript:void(0);'>
											<i style='width:<?php echo esc_attr( $width ); ?>px;height:<?php echo esc_attr( $width ); ?>px' class='<?php echo esc_attr( $class ); ?>'></i>
										</a>
									</div>
											<?php
									} else {
										if ( 'true' === $custom_share ) {
											echo "<a class='asas_share_btn custom " . esc_attr( $key ) . "'  rev='" . esc_url( $social_link ) . "' title='" . esc_html( $val['name'] ) . "' " . esc_html( $bookmark ) . "  href='javascript:void(0);'>";
											if ( $image ) {
												?>
											<img src="<?php echo esc_html( $image ); ?>" height="40" width="40" alt="<?php echo esc_attr( $val['name'] ); ?>" title="<?php echo esc_attr( $val['name'] ); ?>">
													<?php
											}
											echo '</a>';
										} else {
											echo "<a class='asas_share_btn " . esc_attr( $key ) . "'  rev='" . esc_url( $social_link ) . "' title='" . esc_html( $val['name'] ) . "' " . esc_html( $bookmark ) . "  href='javascript:void(0);'></a>";
										}
									}
								}
							}
							?>
					</div>
					<form class="form" id="ajax-share-content-form"> 
						<input type="hidden" name="share_content">
						<input type="hidden" name="social_media">
						<input type="hidden" name="post_id" value="<?php echo esc_attr( $post_id ); ?>">
						<input type="hidden" name="post_type" value="<?php echo esc_attr( $current_post_type ); ?>">
					</form>
					<div class="share-note">
						<?php esc_html_e( "You can't share this post", 'easy-select-and-share' ); ?>
					</div>
				</div>
				<?php
			}
			$out = ob_get_clean();
			if ( 'before_content' === $asas_show_widget_position ) {
				$content = $out . $content;
			} else {
				$content = $content . $out;
			}
		}
		$this->is_used  = $current_filter;
		$this->cur_post = $cur_post;
		return $content;
	}

	/**
	 * Get Short URL
	 *
	 * @param string $url url.
	 * @return string
	 */
	public function esas_get_shorturl( $url ) {
		global $post;

		if ( in_the_loop() ) {
			return rawurlencode( $url );
		} else {
			return rawurlencode( $url );
		}
	}

	/**
	 * Add admin footer
	 *
	 * @return void
	 */
	public function easy_select_and_share_admin_footer() {
		$screen = get_current_screen();
		if ( 'toplevel_page_easy_select_and_share' === $screen->id ) {
			add_filter( 'admin_footer_text', 'esas_remove_footer_admin' );

			/**
			 * Remove and add footer admin content
			 */
			function esas_remove_footer_admin() {
				?>
				<p id="footer-left" class="alignleft">
					<?php esc_html_e( 'If you like ', 'easy-select-and-share' ); ?>
					<strong><a target="_blank" href="https://wordpress.org/plugins/easy-select-and-share/"><?php esc_html_e( 'Easy Select and Share Plugin ', 'easy-select-and-share' ); ?></a></strong>
					<?php esc_html_e( 'please leave us a', 'easy-select-and-share' ); ?>
					<a data-rated="Thanks :)" target="_blank" href="https://www.solwininfotech.com/product/wordpress-plugins/">&#x2605;&#x2605;&#x2605;&#x2605;&#x2605;</a>
					<?php esc_html_e( 'rating. A huge thank you from Solwin Infotech in advance!', 'easy-select-and-share' ); ?>
				</p>
				<?php
			}
		}
	}

	/**
	 * Latest news feed
	 */
	public function esas_latest_news_solwin_feed() {

		// Register the new dashboard widget with the 'wp_dashboard_setup' action.
		add_action( 'wp_dashboard_setup', 'solwin_latest_news_with_product_details' );
		if ( ! function_exists( 'solwin_latest_news_with_product_details' ) ) {

			/**
			 * Solwin site latest post
			 */
			function solwin_latest_news_with_product_details() {
				add_screen_option(
					'layout_columns',
					array(
						'max'     => 3,
						'default' => 2,
					)
				);
				add_meta_box( 'asas_dashboard_widget', esc_html__( 'News From Solwin Infotech', 'easy-select-and-share' ), 'solwin_dashboard_widget_news', 'dashboard', 'normal', 'high' );
			}
		}
		if ( ! function_exists( 'solwin_dashboard_widget_news' ) ) {

			/**
			 * Solwin site data display on dashboard
			 */
			function solwin_dashboard_widget_news() {
				echo '<div class="rss-widget">'
				. '<div class="solwin-news"><p><strong>' . esc_html__( 'Solwin Infotech News', 'easy-select-and-share' ) . '</strong></p>';
				wp_widget_rss_output(
					array(
						'url'          => esc_url( 'https://www.solwininfotech.com/feed/' ),
						'title'        => esc_html__( 'News From Solwin Infotech', 'easy-select-and-share' ),
						'items'        => 5,
						'show_summary' => 0,
						'show_author'  => 0,
						'show_date'    => 1,
					)
				);
				echo '</div>';
				$title     = '';
				$link      = '';
				$thumbnail = '';
				// get Latest product detail from xml file.

				$file = 'https://www.solwininfotech.com/documents/assets/latest_product.xml';
				if ( ! defined( 'LATEST_PRODUCT_FILE' ) ) {
					define( 'LATEST_PRODUCT_FILE', $file );
				}

				echo '<div class="display-product">'
				. '<div class="product-detail"><p><strong>' . esc_html__( 'Latest Product', 'easy-select-and-share' ) . '</strong></p>';
				$response = wp_remote_get( LATEST_PRODUCT_FILE );
				if ( is_wp_error( $response ) ) {
					$error_message = $response->get_error_message();
					echo '<p>' . esc_html__( 'Something went wrong', 'easy-select-and-share' ) . ' : ' . esc_html( $error_message ) . '</p>';
				} else {
					$body      = wp_remote_retrieve_body( $response );
					$xml       = simplexml_load_string( $body );
					$title     = $xml->item->name;
					$thumbnail = $xml->item->img;
					$link      = $xml->item->link;

					$allproducttext      = $xml->item->viewalltext;
					$allproductlink      = $xml->item->viewalllink;
					$moretext            = $xml->item->moretext;
					$needsupporttext     = $xml->item->needsupporttext;
					$needsupportlink     = $xml->item->needsupportlink;
					$customservicetext   = $xml->item->customservicetext;
					$customservicelink   = $xml->item->customservicelink;
					$joinproductclubtext = $xml->item->joinproductclubtext;
					$joinproductclublink = $xml->item->joinproductclublink;

					echo '<div class="product-name"><a href="' . esc_url( $link ) . '" target="_blank">'
					. '<img alt="' . esc_html( $title ) . '" src="' . esc_url( $thumbnail ) . '"> </a>'
					. '<a href="' . esc_url( $link ) . '" target="_blank">' . esc_html( $title ) . '</a>'
					. '<p><a href="' . esc_url( $allproductlink ) . '" target="_blank" class="button button-default">' . esc_html( $allproducttext ) . ' &RightArrow;</a></p>'
					. '<hr>'
					. '<p><strong>' . esc_attr( $moretext ) . '</strong></p>'
					. '<ul>'
					. '<li><a href="' . esc_url( $needsupportlink ) . '" target="_blank">' . esc_html( $needsupporttext ) . '</a></li>'
					. '<li><a href="' . esc_url( $customservicelink ) . '" target="_blank">' . esc_html( $customservicetext ) . '</a></li>'
					. '<li><a href="' . esc_url( $joinproductclublink ) . '" target="_blank">' . esc_html( $joinproductclubtext ) . '</a></li>'
					. '</ul>'
					. '</div>';
				}
				echo '</div></div><div class="clear"></div></div>';
			}
		}
	}

	/**
	 * Reset Setting
	 *
	 * @return void
	 */
	public function esas_reset_default() {

		$asas_custom_lin = array(
			'replace_this' => array(
				'custom_button_text' => '',
				'custom_link_id'     => 'custom_replace_this',
				'custom_share_url'   => '',
				'share_icon'         => '',
			),
		);
		$asas_settings   = array(
			'esc_layout_preset'              => 'esc_layout_preset_5',
			'asas_share_button_type'         => 'icon',
			'asas_icon_text_color'           => '#ffffff',
			'asas_icon_bgcolor'              => '',
			'asas_icon_font_size'            => '16',
			'asas_icon_line_height'          => '20',
			'asas_icon_padding_top'          => '10',
			'asas_icon_padding_right'        => '10',
			'asas_icon_padding_bottom'       => '10',
			'asas_icon_padding_left'         => '10',
			'asas_icon_border_width'         => '0',
			'asas_icon_border_type'          => 'solid',
			'asas_icon_border_color'         => '',
			'asas_icon_border_bottom_width'  => '0',
			'asas_icon_border_bottom_type'   => 'solid',
			'asas_icon_border_bottom_color'  => '',
			'asas_icon_border_left_width'    => '0',
			'asas_icon_border_left_type'     => 'solid',
			'asas_icon_border_left_color'    => '',
			'asas_icon_border_right_width'   => '0',
			'asas_icon_border_right_type'    => 'solid',
			'asas_icon_border_right_color'   => '',
			'asas_icon_border_radius'        => '5',
			'asas_icon_border_rad_type'      => 'px',
			'asas_share_icon_position'       => 'left',
			'asas_text_font_size'            => '14',
			'asas_text_color'                => '#ffffff',
			'asas_text_padding_top'          => '0',
			'asas_text_padding_right'        => '0',
			'asas_text_padding_bottom'       => '0',
			'asas_text_padding_left'         => '0',
			'asas_image_layout'              => 'asas_image_layout_1',
			'asas_show_box_shadow'           => '0',
			'asas_box_shadow_color'          => '',
			'asas_box_padding_top'           => '0',
			'asas_box_padding_right'         => '0',
			'asas_box_padding_bottom'        => '0',
			'asas_box_padding_left'          => '0',
			'asas_box_bgcolor'               => '',
			'asas_box_border_width'          => '0',
			'asas_share_box_border_type'     => 'solid',
			'asas_box_border_color'          => '',
			'asas_box_border_radius'         => '5',
			'asas_box_border_rad_type'       => 'px',
			'asas_widget_title'              => '',
			'asas_title_color'               => '#333',
			'asas_title_background'          => '#ffffff',
			'asas_widget_background'         => '#ffffff',
			'asas_share_widget_border_width' => '0',
			'asas_widget_border_color'       => '#e2e2e2',
			'asas_share_widget_border_type'  => 'solid',
			'asas_widget_border_radius'      => '0',
			'asas_widget_border_rad_type'    => 'px',
			'asas_show_widget_box_shadow'    => '1',
			'asas_widget_box_shadow_color'   => '#e2e2e2',
			'asas_display_close_button'      => '1',
			'asas_widget_extra_class'        => '',
			'asas_widget_width'              => '',
			'asas_widget_width_type'         => '%',
			'share_select'                   => array( 'twitter', 'linkedin', 'facebook' ),
			'asas_supported_posttype'        => array( 'post' ),
			'asas_share_text'                => 'sel',
			'asas_excerpt_limit'             => 60,
			'twitter_username'               => '',
			'facebook_appid'                 => '',
			'asas_show_widget_position'      => 'in_popup',
		);
		update_option( 'asas_settings', $asas_settings );
		echo 'success';
		wp_die();
	}

	/**
	 * Get Easy Select and Share settings
	 *
	 * @return array
	 */
	public function esas_get_option() {
		$asas_settings_key = apply_filters( 'asas_settings', 'asas_settings' );
		$options           = get_option( $asas_settings_key );
		return $options;
	}

	/**
	 * Custom share icon
	 *
	 * @return void
	 */
	public function esas_append_custom_share_icon() {
		$esas_nonce = isset( $_REQUEST['esas_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['esas_nonce'] ) ) : '';
		if ( wp_verify_nonce( $esas_nonce, 'esas_nonce_ajax' ) ) {
			$custom_text       = isset( $_POST['custom_text'] ) ? sanitize_text_field( wp_unslash( $_POST['custom_text'] ) ) : '';
			$custom_url        = isset( $_POST['custom_url'] ) ? sanitize_text_field( wp_unslash( $_POST['custom_url'] ) ) : '';
			$custom_icon       = isset( $_POST['custom_icon'] ) ? sanitize_text_field( wp_unslash( $_POST['custom_icon'] ) ) : '';
			$selected_social   = isset( $_POST['selected_social'] ) ? sanitize_text_field( wp_unslash( $_POST['selected_social'] ) ) : '';
			$no_of_custom_icon = isset( $_POST['no_of_custom_icon'] ) ? sanitize_text_field( wp_unslash( $_POST['no_of_custom_icon'] ) ) : '';

			$custom_slug = strtolower( $custom_text );
			$custom_slug = ltrim( $custom_slug );
			$custom_slug = rtrim( $custom_slug );
			$custom_slug = str_replace( ' ', '-', $custom_slug );

			$append_array = array(
				$custom_slug => array(
					'name'      => $custom_text,
					'titleText' => esc_html__( 'Share this on', 'easy-select-and-share' ) . ' ' . $custom_text,
					'url'       => $custom_url,
				),
			);

			$selectedobj   = new ESASAdminEdit();
			$build_options = $selectedobj->esas_social_bunch();
			$build_options = array_merge( $build_options, $append_array );

			$build_options_keys = array();

			foreach ( $build_options as $key => $value ) {
				$build_options_keys[] = $key;
			}

			$selected          = self::esas_get_option( 'asas_settings' );
			$asas_social_order = get_option( 'asas_social_order' );

			foreach ( $selected_social as $social ) {
				if ( ! in_array( $social, $build_options_keys, true ) ) {
					$not_in_build_option[] = $social;
				}
			}
			?>
			<select data-order='<?php echo esc_attr( $asas_social_order ); ?>' multiple="multiple" class="chosen-select" data-placeholder="<?php esc_html_e( 'Select Social Share options', 'easy-select-and-share' ); ?>"  name="asas_settings[share_select][]" id="share_select">
				<?php
				if ( isset( $selected['share_select'] ) && ! empty( $selected['share_select'] ) ) {
					$share_select = array_merge( $selected['share_select'], array( $custom_slug ) );
				} else {
					$share_select = array( 'twitter', 'linkedin', $custom_slug );
				}

				foreach ( $build_options as $key => $val ) {
					$class = '';
					if ( 'facebook' === $key ) {
						$class = 'facebook_se';
					}
					if ( ! empty( $share_select ) ) {
						?>
						<option class="<?php echo esc_attr( $class ); ?>" value="<?php echo esc_attr( $key ); ?>" <?php echo in_array( $key, $share_select, true ) ? 'selected="selected"' : ''; ?>><?php echo esc_attr( $val['name'] ); ?></option>
						<?php
					} else {
						?>
						<option class="<?php echo esc_attr( $class ); ?>" value="<?php echo esc_attr( $key ); ?>"><?php echo esc_attr( $val['name'] ); ?></option>
						<?php
					}
				}
				foreach ( $not_in_build_option as $option ) {
					?>
					<option class="<?php echo esc_attr( $class ); ?>" selected="selected" value="<?php echo esc_attr( $option ); ?>"><?php echo esc_attr( ucwords( $option ) ); ?></option>
					<?php
				}
				?>
			</select>
			<?php
			exit;
		}
	}

	/**
	 * Custom Excerpt length
	 *
	 * @param string $length Length.
	 * @return string
	 */
	public function esas_custom_excerpt_length( $length ) {
		$options        = self::esas_get_option();
		$excerpt_length = $options['asas_excerpt_limit'];
		return $excerpt_length;
	}

	/**
	 * Insert Logs
	 *
	 * @return void
	 */
	public function esas_insert_log() {
		global $wpdb;
		$share_content = '';
		$social_media  = '';
		$post_id       = '';
		$post_type     = '';
		$esas_nonce    = isset( $_POST['esas_front_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['esas_front_nonce'] ) ) : '';
		if ( wp_verify_nonce( $esas_nonce, 'esas_front_nonce_ajax' ) ) {
			if ( isset( $_POST['share_content'] ) ) {
				$share_content = sanitize_text_field( wp_unslash( $_POST['share_content'] ) );
			}
			if ( isset( $_POST['social_media'] ) ) {
				$social_media = sanitize_text_field( wp_unslash( $_POST['social_media'] ) );
			}
			if ( isset( $_POST['post_id'] ) ) {
				$post_id = sanitize_text_field( wp_unslash( $_POST['post_id'] ) );
			}
			if ( isset( $_POST['post_type'] ) ) {
				$post_type = sanitize_text_field( wp_unslash( $_POST['post_type'] ) );
			}
			$post_name    = get_the_title( $post_id );
			$current_date = gmdate( 'Y-m-d g:i:s A' );
			$data         = array(
				'share_content' => $share_content,
				'social_media'  => $social_media,
				'post_id'       => $post_id,
				'post_type'     => $post_type,
				'post_name'     => $post_name,
				'share_date'    => $current_date,
			);
			$result       = $wpdb->insert( $wpdb->prefix . 'sas_log', $data );
			if ( $result ) {
				echo 'success';
			} else {
				$wpdb->show_errors();
			}
		}
		die();
	}
	/**
	 * Push hidden Post Data
	 *
	 * @return void
	 */
	public function esas_footer_by_class_content() {
		global $post;
		$out                       = '';
		$content                   = '';
		$to_be_replaced            = array();
		$current_filter            = current_filter();
		$cur_post                  = isset( $post->ID ) ? $post->ID : '';
		$asas_add_soc              = 'yes';
		$current_post_type         = get_post_type( $cur_post );
		$options                   = self::esas_get_option();
		$asas_show_widget_position = 'in_popup';
		$email                     = get_bloginfo( 'admin_email' );
		$selected                  = isset( $options['share_select'] ) ? $options['share_select'] : array( 'twitter', 'linkedin' );
		$build_options             = $this->esas_admin_edit->esas_social_bunch();
		$extra_class               = isset( $options['asas_widget_extra_class'] ) ? $options['asas_widget_extra_class'] : '';
		$rss                       = ( empty( $options['rssurl'] ) ) ? get_bloginfo( 'rss_url' ) : $options['rssurl'];
		$text_to_share             = ( ! empty( $options['asas_share_text'] ) ) ? $options['asas_share_text'] : 'sel';
		$blogname                  = rawurlencode( get_bloginfo( 'name' ) . ' - ' . get_bloginfo( 'description' ) );
		$twitterusername           = ( empty( $options['twitter_username'] ) ) ? '' : $options['twitter_username'];
		$facebook_appid            = ( empty( $options['facebook_appid'] ) ) ? '' : $options['facebook_appid'];
		$asas_show_box_shadow      = isset( $options['asas_show_box_shadow'] ) ? $options['asas_show_box_shadow'] : '1';
		$asas_share_button_type    = isset( $options['asas_share_button_type'] ) ? $options['asas_share_button_type'] : 'icon';
		$asas_image_layout         = isset( $options['asas_image_layout'] ) ? $options['asas_image_layout'] : 'asas_image_layout_1';
		$esc_layout_preset         = isset( $options['esc_layout_preset'] ) ? $options['esc_layout_preset'] : 'esc_layout_preset_5';
		$asas_widget_title         = isset( $options['asas_widget_title'] ) ? $options['asas_widget_title'] : '';
		$asas_share_icon_position  = isset( $options['asas_share_icon_position'] ) ? $options['asas_share_icon_position'] : 'left';
		$padding_left              = ( isset( $options['asas_icon_padding_left'] ) && '' !== $options['asas_icon_padding_left'] ) ? $options['asas_icon_padding_left'] : '10';
		$padding_right             = ( isset( $options['asas_icon_padding_right'] ) && '' !== $options['asas_icon_padding_right'] ) ? $options['asas_icon_padding_right'] : '10';
		$asas_icon_font_size       = ( isset( $options['asas_icon_font_size'] ) && '' !== $options['asas_icon_font_size'] ) ? $options['asas_icon_font_size'] : '16';
		$asas_show_box_shadow      = isset( $options['asas_show_box_shadow'] ) ? $options['asas_show_box_shadow'] : '0';
		$asas_display_close_button = isset( $options['asas_display_close_button'] ) ? $options['asas_display_close_button'] : '1';

		$post_id          = get_the_ID();
		$post_url         = get_permalink( $post_id );
		$post_title       = get_the_title( $post_id );
		$all_data         = get_post( $post_id );
		$sol_post_content = isset( $all_data->post_content ) ? $all_data->post_content : '';
		$post_content     = $this->esas_get_trim_content( $sol_post_content, $post_id );

		if ( has_excerpt( $post_id ) ) {
			$post_content = get_the_excerpt( $post_id );
		} else {
			$post_content = get_the_content( $post_id );
		}
		$post_short_url = $this->esas_get_shorturl( $post_url );
		if ( isset( $options['enable_shortlinks'] ) ) {
			$post_url = wp_get_shortlink( $post_id );
		}
		$post_content = wp_strip_all_tags( $post_content );
		$asas_words   = explode( ' ', $post_content );
		$cat_str      = '';
		$post_thumb   = $this->esas_get_post_thumbnail_url( $post_id, $post_content );
		if ( 'yes' === $asas_add_soc ) {
			?>
			<div class='shareit_by_class
					<?php
					if ( '' !== $asas_show_widget_position ) {
						echo esc_attr( $asas_show_widget_position ) . ' ';
					}
					if ( '' !== $asas_image_layout ) {
						echo esc_attr( $asas_image_layout ) . ' ';
					}
					if ( '' !== $esc_layout_preset ) {
						echo esc_attr( $esc_layout_preset ) . ' ';
					}
					if ( '' !== $asas_share_button_type ) {
						echo 'asas_button_type_' . esc_attr( $asas_share_button_type ) . ' ';
					}
					echo esc_attr( $extra_class );
					?>
			' style="display: none;">
				<div class="shareit_hidden_post_data" style="display: none">
					<input type="hidden" class="shareit_post_id" name="shareit_post_id" value="<?php echo esc_attr( $post_id ); ?>">
					<input type="hidden" class="shareit_post_type" name="shareit_post_type" value="<?php echo esc_attr( $current_post_type ); ?>">
					<input type="hidden" class="shareit_post_cat" name="shareit_post_cat" value="<?php echo esc_attr( $cat_str ); ?>">
				</div>
				<?php if ( '' !== $asas_widget_title || '1' === $asas_display_close_button ) { ?>
					<div class="share-this-popup-top">
						<?php
						if ( '' !== $asas_widget_title ) :
							?>
							<div class="share-it-title"><strong><?php echo esc_attr( $asas_widget_title ); ?></strong></div>
							<?php
						endif;
						if ( '1' === $asas_display_close_button && ( 'beside_selected_text' === $asas_show_widget_position || 'in_popup' === $asas_show_widget_position ) ) {
							?>
							<a class="popup-close-btn-by-class" href="javascript:void(0);"></a>
						<?php } ?>
					</div>
				<?php } ?>
				<div class="share-icon-wrapper 
				<?php
				if ( '0' !== $asas_show_box_shadow ) {
					echo 'asas_box_shadow_enable ';
				}
				?>
						">
							<?php
							$asas_social_order = get_option( 'asas_social_order' );
							if ( '' === $asas_social_order ) {
								$asas_social_order = 'twitter, linkedin, facebook';
							}
							$key               = '';
							$asas_social_order = explode( ',', $asas_social_order );
							array_pop( $asas_social_order );
							foreach ( $asas_social_order as $asas_social ) {
								if ( isset( $asas_social ) && '' !== $asas_social ) {
									$asas_social = trim( $asas_social );
									if ( isset( $build_options[ $asas_social ] ) ) {
										$val = $build_options[ $asas_social ];
										$key = $asas_social;
									}
								}
								if ( in_array( trim( $key ), $selected, true ) ) {
										$replace_with   = array(
											rawurlencode( $post_url ),
											rawurlencode( $post_title ),
											$rss,
											$blogname,
											$post_url,
											$post_title,
											$email,
											$twitterusername,
											$post_short_url,
											$post_thumb,
											$facebook_appid,
										);
										$to_be_replaced = array(
											'{url}',
											'{title}',
											'{rss-url}',
											'{blogname}',
											'{de-url}',
											'{de-title}',
											'{email_address}',
											'{twitter-username}',
											'{s-url}',
											'{image}',
											'{app_id}',
										);
										$bookmark       = '';
										if ( 'addtofavorites' === $key ) {
											$bookmark = 'onclick=addBookmark(event);';
										}
										$custom_share = 'false';

										$image = ( isset( $build_options[ $key ]['image'] ) && '' !== $build_options[ $key ]['image'] ) ? $build_options[ $key ]['image'] : '';
										$icon  = ( isset( $build_options[ $key ]['icon'] ) && '' !== $build_options[ $key ]['icon'] ) ? $build_options[ $key ]['icon'] : '';
										if ( 'facebook' === $key && '' === $facebook_appid ) {
											continue;
										}

										if ( 'facebook' === $key || 'linkedin' === $key || 'tumblr' === $key || 'twitter' === $key || 'email' === $key || 'skype' === $key || 'vk' === $key || 'whatsapp' === $key || 'xing' === $key || 'pinterest' === $key || 'blogger' === $key || 'reddit' === $key || 'wikipedia' === $key || 'buffer' === $key ) {
											$class = ( isset( $options[ $key . '_icon' ] ) && '' !== $options[ $key . '_icon' ] ) ? $options[ $key . '_icon' ] : $build_options[ $key ]['icon'];
										} else {
											$custom_share = 'true';
											$class        = $key . ' ' . $icon;
										}

										$height      = '40px';
										$width       = '40px';
										$height      = $padding_left + $padding_right + $asas_icon_font_size + 5;
										$width       = $padding_left + $padding_right + $asas_icon_font_size + 5;
										$social_link = str_replace( $to_be_replaced, $replace_with, $val['url'] );
										if ( 'icon' === $asas_share_button_type ) {
											?>
								<div class='share-icon-item <?php echo esc_attr( $key ); ?>'><a class='asas_share_btn <?php echo esc_attr( $key ); ?>' rev='<?php echo esc_url( $social_link ); ?>' title='<?php echo esc_html( $val['name'] ); ?>' <?php echo esc_html( $bookmark ); ?> href='javascript:void(0);'>
										<i style='width:<?php echo esc_attr( $width ); ?>px;height:<?php echo esc_attr( $width ); ?>px' class='<?php echo esc_attr( $class ); ?>'></i>
									</a>
								</div>
											<?php
										} else {
											if ( 'true' === $custom_share ) {
												echo "<a class='asas_share_btn custom " . esc_attr( $key ) . "'  rev='" . esc_url( $social_link ) . "' title='" . esc_html( $val['name'] ) . "' " . esc_html( $bookmark ) . "  href='javascript:void(0);'>";
												if ( $image ) {
													?>
										<img src="<?php echo esc_html( $image ); ?>" height="40" width="40" alt="<?php echo esc_attr( $val['name'] ); ?>" title="<?php echo esc_attr( $val['name'] ); ?>">
													<?php
												}
												echo '</a>';
											} else {
												echo "<a class='asas_share_btn " . esc_attr( $key ) . "'  rev='" . esc_url( $social_link ) . "' title='" . esc_html( $val['name'] ) . "' " . esc_html( $bookmark ) . "  href='javascript:void(0);'></a>";
											}
										}
								}
							}
							?>
				</div>
				<form class="form" id="ajax-share-content-form"> 
					<input type="hidden" name="share_content">
					<input type="hidden" name="social_media">
					<input type="hidden" name="post_id" value="<?php echo esc_attr( $post_id ); ?>">
					<input type="hidden" name="post_type" value="<?php echo esc_attr( $current_post_type ); ?>">
				</form>
				<div class="share-note">
					<?php esc_html_e( "You can't share this post", 'easy-select-and-share' ); ?>
				</div>
			</div>
			<?php
		}
	}
}
new EasySelectandShare();
